def electric_current(value, units):
	returnDict = {}
	if units == 'amp':
		returnDict['amp'] = value
		returnDict['biot'] = value * 0.1
		returnDict['camp'] = value * 100.0
		returnDict['gilbert'] = value * 1.2566371
		returnDict['kamp'] = value * 0.001
		returnDict['mamp'] = value * 1000.0
		returnDict['v/ohm'] = value
		returnDict['w/v'] = value
	elif units == 'biot':
		returnDict['amp'] = value * 10.0
		returnDict['biot'] = value
		returnDict['camp'] = value * 1000.0
		returnDict['gilbert'] = value * 12.5663709
		returnDict['kamp'] = value * 0.01
		returnDict['mamp'] = value * 10000.0
		returnDict['v/ohm'] = value * 10.0
		returnDict['w/v'] = value * 10.0
	elif units == 'camp':
		returnDict['amp'] = value * 0.01
		returnDict['biot'] = value * 0.001
		returnDict['camp'] = value
		returnDict['gilbert'] = value * 0.0125664
		returnDict['kamp'] = value * 1e-05
		returnDict['mamp'] = value * 10.0
		returnDict['v/ohm'] = value * 0.01
		returnDict['w/v'] = value * 0.01
	elif units == 'gilbert':
		returnDict['amp'] = value * 0.7957747
		returnDict['biot'] = value * 0.0795775
		returnDict['camp'] = value * 79.57747
		returnDict['gilbert'] = value
		returnDict['kamp'] = value * 0.0007958
		returnDict['mamp'] = value * 795.7747
		returnDict['v/ohm'] = value * 0.7957747
		returnDict['w/v'] = value * 0.7957747
	elif units == 'kamp':
		returnDict['amp'] = value * 1000.0
		returnDict['biot'] = value * 100.0
		returnDict['camp'] = value * 100000.0
		returnDict['gilbert'] = value * 1256.6370858
		returnDict['kamp'] = value
		returnDict['mamp'] = value * 1000000.0
		returnDict['v/ohm'] = value * 1000.0
		returnDict['w/v'] = value * 1000.0
	elif units == 'mamp':
		returnDict['amp'] = value * 0.001
		returnDict['biot'] = value * 0.0001
		returnDict['camp'] = value * 0.1
		returnDict['gilbert'] = value * 0.0012566
		returnDict['kamp'] = value * 1e-06
		returnDict['mamp'] = value
		returnDict['v/ohm'] = value * 0.001
		returnDict['w/v'] = value * 0.001
	elif units == 'v/ohm':
		returnDict['amp'] = value
		returnDict['biot'] = value * 0.1
		returnDict['camp'] = value * 100.0
		returnDict['gilbert'] = value * 1.2566371
		returnDict['kamp'] = value * 0.001
		returnDict['mamp'] = value * 1000.0
		returnDict['v/ohm'] = value
		returnDict['w/v'] = value
	elif units == 'w/v':
		returnDict['amp'] = value
		returnDict['biot'] = value * 0.1
		returnDict['camp'] = value * 100.0
		returnDict['gilbert'] = value * 1.2566371
		returnDict['kamp'] = value * 0.001
		returnDict['mamp'] = value * 1000.0
		returnDict['v/ohm'] = value
		returnDict['w/v'] = value
	return returnDict

def fracture_conductivity(value, units):
	returnDict = {}
	if units == 'darcy-in':
		returnDict['darcy-in'] = value
		returnDict['mu.m2-m'] = value * 22.7837142
	elif units == 'mu.m2-m':
		returnDict['darcy-in'] = value * 0.043891
		returnDict['mu.m2-m'] = value
	return returnDict

def heat_capacity(value, units):
	returnDict = {}
	if units == 'Btu/lb-F':
		returnDict['Btu/lb-F'] = value
		returnDict['J/kg-C'] = value * 4186.8
	elif units == 'J/kg-C':
		returnDict['Btu/lb-F'] = value * 0.0002388
		returnDict['J/kg-C'] = value
	return returnDict

def power_area(value, units):
	returnDict = {}
	if units == 'HP/in2':
		returnDict['HP/in2'] = value
		returnDict['kW/mm2'] = value * 0.001156
	elif units == 'kW/mm2':
		returnDict['HP/in2'] = value * 865.0519031
		returnDict['kW/mm2'] = value
	return returnDict

def angular_velocity(value, units):
	returnDict = {}
	if units == 'deg/hr':
		returnDict['deg/hr'] = value
		returnDict['deg/min'] = value * 0.0166667
		returnDict['deg/sec'] = value * 0.0002778
		returnDict['rad/hr'] = value * 0.0174533
		returnDict['rad/min'] = value * 0.0002909
		returnDict['rad/sec'] = value * 4.8e-06
		returnDict['rph'] = value * 0.0027778
		returnDict['rpm'] = value * 4.63e-05
		returnDict['rps'] = value * 7.72e-07
	elif units == 'deg/min':
		returnDict['deg/hr'] = value * 60.0
		returnDict['deg/min'] = value
		returnDict['deg/sec'] = value * 0.0166667
		returnDict['rad/hr'] = value * 1.0471976
		returnDict['rad/min'] = value * 0.0174533
		returnDict['rad/sec'] = value * 0.0002909
		returnDict['rph'] = value * 0.1666667
		returnDict['rpm'] = value * 0.0027778
		returnDict['rps'] = value * 4.63e-05
	elif units == 'deg/sec':
		returnDict['deg/hr'] = value * 3600.0
		returnDict['deg/min'] = value * 60.0
		returnDict['deg/sec'] = value
		returnDict['rad/hr'] = value * 62.8318543
		returnDict['rad/min'] = value * 1.0471976
		returnDict['rad/sec'] = value * 0.0174533
		returnDict['rph'] = value * 10.0
		returnDict['rpm'] = value * 0.1666667
		returnDict['rps'] = value * 0.0027778
	elif units == 'rad/hr':
		returnDict['deg/hr'] = value * 57.2957784
		returnDict['deg/min'] = value * 0.9549296
		returnDict['deg/sec'] = value * 0.0159155
		returnDict['rad/hr'] = value
		returnDict['rad/min'] = value * 0.0166667
		returnDict['rad/sec'] = value * 0.0002778
		returnDict['rph'] = value * 0.1591549
		returnDict['rpm'] = value * 0.0026526
		returnDict['rps'] = value * 4.42e-05
	elif units == 'rad/min':
		returnDict['deg/hr'] = value * 3437.746704
		returnDict['deg/min'] = value * 57.2957784
		returnDict['deg/sec'] = value * 0.9549296
		returnDict['rad/hr'] = value * 60.0
		returnDict['rad/min'] = value
		returnDict['rad/sec'] = value * 0.0166667
		returnDict['rph'] = value * 9.5492964
		returnDict['rpm'] = value * 0.1591549
		returnDict['rps'] = value * 0.0026526
	elif units == 'rad/sec':
		returnDict['deg/hr'] = value * 206264.80224
		returnDict['deg/min'] = value * 3437.746704
		returnDict['deg/sec'] = value * 57.2957784
		returnDict['rad/hr'] = value * 3600.0
		returnDict['rad/min'] = value * 60.0
		returnDict['rad/sec'] = value
		returnDict['rph'] = value * 572.957784
		returnDict['rpm'] = value * 9.5492964
		returnDict['rps'] = value * 0.1591549
	elif units == 'rph':
		returnDict['deg/hr'] = value * 360.0
		returnDict['deg/min'] = value * 6.0
		returnDict['deg/sec'] = value * 0.1
		returnDict['rad/hr'] = value * 6.2831854
		returnDict['rad/min'] = value * 0.1047198
		returnDict['rad/sec'] = value * 0.0017453
		returnDict['rph'] = value
		returnDict['rpm'] = value * 0.0166667
		returnDict['rps'] = value * 0.0002778
	elif units == 'rpm':
		returnDict['deg/hr'] = value * 21600.0
		returnDict['deg/min'] = value * 360.0
		returnDict['deg/sec'] = value * 6.0
		returnDict['rad/hr'] = value * 376.9911258
		returnDict['rad/min'] = value * 6.2831854
		returnDict['rad/sec'] = value * 0.1047198
		returnDict['rph'] = value * 60.0
		returnDict['rpm'] = value
		returnDict['rps'] = value * 0.0166667
	elif units == 'rps':
		returnDict['deg/hr'] = value * 1296000.0
		returnDict['deg/min'] = value * 21600.0
		returnDict['deg/sec'] = value * 360.0
		returnDict['rad/hr'] = value * 22619.4675453
		returnDict['rad/min'] = value * 376.9911258
		returnDict['rad/sec'] = value * 6.2831854
		returnDict['rph'] = value * 3600.0
		returnDict['rpm'] = value * 60.0
		returnDict['rps'] = value
	return returnDict

def force(value, units):
	returnDict = {}
	if units == 'daN':
		returnDict['daN'] = value
		returnDict['dyn'] = value * 1000000.0
		returnDict['gf'] = value * 1019.72
		returnDict['kgf'] = value * 1.02
		returnDict['kN'] = value * 0.01
		returnDict['kip'] = value * 0.00225
		returnDict['klbs'] = value * 0.00225
		returnDict['MN'] = value * 1e-05
		returnDict['N'] = value * 10.0
		returnDict['ozf'] = value * 35.97
		returnDict['lbf'] = value * 2.25
		returnDict['pdl'] = value * 72.39
		returnDict['sn'] = value * 0.01
		returnDict['tf-metric'] = value * 0.00102
		returnDict['tf-long'] = value * 0.001
		returnDict['tf-short'] = value * 0.00112
		returnDict['hN'] = value * 0.1
		returnDict['J/m'] = value
		returnDict['mN'] = value * 10000.0
	elif units == 'dyn':
		returnDict['daN'] = value * 1e-06
		returnDict['dyn'] = value
		returnDict['gf'] = value * 0.00102
		returnDict['kgf'] = value * 1.02e-06
		returnDict['kN'] = value * 1e-08
		returnDict['kip'] = value * 2.25e-09
		returnDict['klbs'] = value * 2.25e-09
		returnDict['MN'] = value * 1e-11
		returnDict['N'] = value * 1e-05
		returnDict['ozf'] = value * 3.6e-05
		returnDict['lbf'] = value * 2.25e-06
		returnDict['pdl'] = value * 7.2e-05
		returnDict['sn'] = value * 9.95e-09
		returnDict['tf-metric'] = value * 1.01e-09
		returnDict['tf-long'] = value * 9.94e-10
		returnDict['tf-short'] = value * 1.11e-09
		returnDict['hN'] = value * 1.0000000000000001e-07
		returnDict['J/m'] = value * 1e-05
		returnDict['mN'] = value * 0.01
	elif units == 'gf':
		returnDict['daN'] = value * 0.00098
		returnDict['dyn'] = value * 980.0
		returnDict['gf'] = value
		returnDict['kgf'] = value * 0.001
		returnDict['kN'] = value * 9.8e-06
		returnDict['kip'] = value * 2.2e-06
		returnDict['klbs'] = value * 2.2e-06
		returnDict['MN'] = value * 9.79e-09
		returnDict['N'] = value * 0.01
		returnDict['ozf'] = value * 0.04
		returnDict['lbf'] = value * 0.0022
		returnDict['pdl'] = value * 0.07
		returnDict['sn'] = value * 9.8e-06
		returnDict['tf-metric'] = value * 1e-06
		returnDict['tf-long'] = value * 9.84e-07
		returnDict['tf-short'] = value * 1.1e-06
		returnDict['hN'] = value * 0.0001
		returnDict['J/m'] = value * 0.01
		returnDict['mN'] = value * 10.0
	elif units == 'kgf':
		returnDict['daN'] = value * 0.98
		returnDict['dyn'] = value * 980665.0
		returnDict['gf'] = value * 1000.0
		returnDict['kgf'] = value
		returnDict['kN'] = value * 0.01
		returnDict['kip'] = value * 0.0022
		returnDict['klbs'] = value * 0.0022
		returnDict['MN'] = value * 9.8e-06
		returnDict['N'] = value * 9.81
		returnDict['ozf'] = value * 35.27
		returnDict['lbf'] = value * 2.2
		returnDict['pdl'] = value * 70.93
		returnDict['sn'] = value * 0.01
		returnDict['tf-metric'] = value * 0.001
		returnDict['tf-long'] = value * 0.00098
		returnDict['tf-short'] = value * 0.0011
		returnDict['hN'] = value * 0.0981
		returnDict['J/m'] = value * 9.81
		returnDict['mN'] = value * 9810.0
	elif units == 'kN':
		returnDict['daN'] = value * 100.0
		returnDict['dyn'] = value * 100000000.0
		returnDict['gf'] = value * 101971.62
		returnDict['kgf'] = value * 101.97
		returnDict['kN'] = value
		returnDict['kip'] = value * 0.22
		returnDict['klbs'] = value * 0.22
		returnDict['MN'] = value * 0.001
		returnDict['N'] = value * 1000.0
		returnDict['ozf'] = value * 3596.94
		returnDict['lbf'] = value * 224.81
		returnDict['pdl'] = value * 7233.05
		returnDict['sn'] = value
		returnDict['tf-metric'] = value * 0.1
		returnDict['tf-long'] = value * 0.098
		returnDict['tf-short'] = value * 0.11
		returnDict['hN'] = value * 10.0
		returnDict['J/m'] = value * 1000.0
		returnDict['mN'] = value * 1000000.0
	elif units == 'kip':
		returnDict['daN'] = value * 444.82
		returnDict['dyn'] = value * 445000000.0
		returnDict['gf'] = value * 453592.37
		returnDict['kgf'] = value * 453.59
		returnDict['kN'] = value * 4.45
		returnDict['kip'] = value
		returnDict['klbs'] = value
		returnDict['MN'] = value * 0.00445
		returnDict['N'] = value * 4448.22
		returnDict['ozf'] = value * 16000.0
		returnDict['lbf'] = value * 1000.0
		returnDict['pdl'] = value * 32174.05
		returnDict['sn'] = value * 4.45
		returnDict['tf-metric'] = value * 0.45
		returnDict['tf-long'] = value * 0.45
		returnDict['tf-short'] = value * 0.5
		returnDict['hN'] = value * 44.482200000000006
		returnDict['J/m'] = value * 4448.22
		returnDict['mN'] = value * 4448220.0
	elif units == 'klbs':
		returnDict['daN'] = value * 444.82
		returnDict['dyn'] = value * 445000000.0
		returnDict['gf'] = value * 453592.37
		returnDict['kgf'] = value * 453.59
		returnDict['kN'] = value * 4.45
		returnDict['kip'] = value
		returnDict['klbs'] = value
		returnDict['MN'] = value * 0.00445
		returnDict['N'] = value * 4448.22
		returnDict['ozf'] = value * 16000.0
		returnDict['lbf'] = value * 1000.0
		returnDict['pdl'] = value * 32174.05
		returnDict['sn'] = value * 4.45
		returnDict['tf-metric'] = value * 0.45
		returnDict['tf-long'] = value * 0.45
		returnDict['tf-short'] = value * 0.5
		returnDict['hN'] = value * 44.482200000000006
		returnDict['J/m'] = value * 4448.22
		returnDict['mN'] = value * 4448220.0
	elif units == 'MN':
		returnDict['daN'] = value * 100000.0
		returnDict['dyn'] = value * 100000000000.0
		returnDict['gf'] = value * 102000000.0
		returnDict['kgf'] = value * 101971.62
		returnDict['kN'] = value * 1000.0
		returnDict['kip'] = value * 224.81
		returnDict['klbs'] = value * 224.81
		returnDict['MN'] = value
		returnDict['N'] = value * 1000000.0
		returnDict['ozf'] = value * 3596943.09
		returnDict['lbf'] = value * 224808.94
		returnDict['pdl'] = value * 7233013.85
		returnDict['sn'] = value * 1000.0
		returnDict['tf-metric'] = value * 101.97
		returnDict['tf-long'] = value * 100.36
		returnDict['tf-short'] = value * 112.4
		returnDict['hN'] = value * 10000.0
		returnDict['J/m'] = value * 1000000.0
		returnDict['mN'] = value * 1000000000.0
	elif units == 'N':
		returnDict['daN'] = value * 0.1
		returnDict['dyn'] = value * 100000.0
		returnDict['gf'] = value * 101.97
		returnDict['kgf'] = value * 0.1
		returnDict['kN'] = value * 0.001
		returnDict['kip'] = value * 0.000225
		returnDict['klbs'] = value * 0.000225
		returnDict['MN'] = value * 1e-06
		returnDict['N'] = value
		returnDict['ozf'] = value * 3.6
		returnDict['lbf'] = value * 0.22
		returnDict['pdl'] = value * 7.23
		returnDict['sn'] = value * 0.001
		returnDict['tf-metric'] = value * 0.000102
		returnDict['tf-long'] = value * 0.0001
		returnDict['tf-short'] = value * 0.000112
		returnDict['hN'] = value * 0.01
		returnDict['J/m'] = value
		returnDict['mN'] = value * 1000.0
	elif units == 'ozf':
		returnDict['daN'] = value * 0.03
		returnDict['dyn'] = value * 27801.39
		returnDict['gf'] = value * 28.35
		returnDict['kgf'] = value * 0.03
		returnDict['kN'] = value * 0.000278
		returnDict['kip'] = value * 6.3e-05
		returnDict['klbs'] = value * 6.3e-05
		returnDict['MN'] = value * 2.78e-07
		returnDict['N'] = value * 0.28
		returnDict['ozf'] = value
		returnDict['lbf'] = value * 0.06
		returnDict['pdl'] = value * 2.01
		returnDict['sn'] = value * 0.000278
		returnDict['tf-metric'] = value * 2.83e-05
		returnDict['tf-long'] = value * 2.79e-05
		returnDict['tf-short'] = value * 3.13e-05
		returnDict['hN'] = value * 0.0028000000000000004
		returnDict['J/m'] = value * 0.28
		returnDict['mN'] = value * 280.0
	elif units == 'lbf':
		returnDict['daN'] = value * 0.44
		returnDict['dyn'] = value * 444822.16
		returnDict['gf'] = value * 453.59
		returnDict['kgf'] = value * 0.45
		returnDict['kN'] = value * 0.00445
		returnDict['kip'] = value * 0.001
		returnDict['klbs'] = value * 0.001
		returnDict['MN'] = value * 4.45e-06
		returnDict['N'] = value * 4.45
		returnDict['ozf'] = value * 16.0
		returnDict['lbf'] = value
		returnDict['pdl'] = value * 32.17
		returnDict['sn'] = value * 0.00445
		returnDict['tf-metric'] = value * 0.000454
		returnDict['tf-long'] = value * 0.000446
		returnDict['tf-short'] = value * 0.0005
		returnDict['hN'] = value * 0.044500000000000005
		returnDict['J/m'] = value * 4.45
		returnDict['mN'] = value * 4450.0
	elif units == 'pdl':
		returnDict['daN'] = value * 0.01
		returnDict['dyn'] = value * 13825.5
		returnDict['gf'] = value * 14.1
		returnDict['kgf'] = value * 0.01
		returnDict['kN'] = value * 0.000138
		returnDict['kip'] = value * 3.11e-05
		returnDict['klbs'] = value * 3.11e-05
		returnDict['MN'] = value * 1.38e-07
		returnDict['N'] = value * 0.14
		returnDict['ozf'] = value * 0.5
		returnDict['lbf'] = value * 0.03
		returnDict['pdl'] = value
		returnDict['sn'] = value * 0.000138
		returnDict['tf-metric'] = value * 1.41e-05
		returnDict['tf-long'] = value * 1.39e-05
		returnDict['tf-short'] = value * 1.55e-05
		returnDict['hN'] = value * 0.0014000000000000002
		returnDict['J/m'] = value * 0.14
		returnDict['mN'] = value * 140.0
	elif units == 'sn':
		returnDict['daN'] = value * 100.0
		returnDict['dyn'] = value * 100000000.0
		returnDict['gf'] = value * 101971.62
		returnDict['kgf'] = value * 101.97
		returnDict['kN'] = value
		returnDict['kip'] = value * 0.22
		returnDict['klbs'] = value * 0.22
		returnDict['MN'] = value * 0.001
		returnDict['N'] = value * 1000.0
		returnDict['ozf'] = value * 3596.94
		returnDict['lbf'] = value * 224.81
		returnDict['pdl'] = value * 7233.01
		returnDict['sn'] = value
		returnDict['tf-metric'] = value * 0.1
		returnDict['tf-long'] = value * 0.098
		returnDict['tf-short'] = value * 0.11
		returnDict['hN'] = value * 10.0
		returnDict['J/m'] = value * 1000.0
		returnDict['mN'] = value * 1000000.0
	elif units == 'tf-metric':
		returnDict['daN'] = value * 980.66
		returnDict['dyn'] = value * 981000000.0
		returnDict['gf'] = value * 1000000.0
		returnDict['kgf'] = value * 1000.0
		returnDict['kN'] = value * 9.81
		returnDict['kip'] = value * 2.2
		returnDict['klbs'] = value * 2.2
		returnDict['MN'] = value * 0.01
		returnDict['N'] = value * 9806.65
		returnDict['ozf'] = value * 35273.96
		returnDict['lbf'] = value * 2204.62
		returnDict['pdl'] = value * 70931.64
		returnDict['sn'] = value * 9.81
		returnDict['tf-metric'] = value
		returnDict['tf-long'] = value * 0.98
		returnDict['tf-short'] = value * 1.1
		returnDict['hN'] = value * 98.06649999999999
		returnDict['J/m'] = value * 9806.65
		returnDict['mN'] = value * 9806650.0
	elif units == 'tf-long':
		returnDict['daN'] = value * 996.4
		returnDict['dyn'] = value * 996000000.0
		returnDict['gf'] = value * 1016046.91
		returnDict['kgf'] = value * 1016.05
		returnDict['kN'] = value * 9.96
		returnDict['kip'] = value * 2.24
		returnDict['klbs'] = value * 2.24
		returnDict['MN'] = value * 0.01
		returnDict['N'] = value * 9964.02
		returnDict['ozf'] = value * 35840.0
		returnDict['lbf'] = value * 2240.0
		returnDict['pdl'] = value * 72069.87
		returnDict['sn'] = value * 9.96
		returnDict['tf-metric'] = value * 1.02
		returnDict['tf-long'] = value
		returnDict['tf-short'] = value * 1.12
		returnDict['hN'] = value * 99.64020000000001
		returnDict['J/m'] = value * 9964.02
		returnDict['mN'] = value * 9964020.0
	elif units == 'tf-short':
		returnDict['daN'] = value * 889.64
		returnDict['dyn'] = value * 890000000.0
		returnDict['gf'] = value * 907184.74
		returnDict['kgf'] = value * 907.18
		returnDict['kN'] = value * 8.9
		returnDict['kip'] = value * 2.0
		returnDict['klbs'] = value * 2.0
		returnDict['MN'] = value * 0.01
		returnDict['N'] = value * 8896.44
		returnDict['ozf'] = value * 32000.0
		returnDict['lbf'] = value * 2000.0
		returnDict['pdl'] = value * 64348.1
		returnDict['sn'] = value * 8.9
		returnDict['tf-metric'] = value * 0.91
		returnDict['tf-long'] = value * 0.89
		returnDict['tf-short'] = value
		returnDict['hN'] = value * 88.96440000000001
		returnDict['J/m'] = value * 8896.44
		returnDict['mN'] = value * 8896440.0
	elif units == 'hN':
		returnDict['daN'] = value * 10.0
		returnDict['dyn'] = value * 10000000.0
		returnDict['gf'] = value * 10197.16
		returnDict['kgf'] = value * 10.2
		returnDict['kN'] = value * 0.1
		returnDict['kip'] = value * 0.02
		returnDict['klbs'] = value * 0.02
		returnDict['MN'] = value * 0.0001
		returnDict['N'] = value * 100.0
		returnDict['ozf'] = value * 359.69
		returnDict['lbf'] = value * 22.48
		returnDict['pdl'] = value * 723.3
		returnDict['sn'] = value * 0.1
		returnDict['tf-metric'] = value * 0.01
		returnDict['tf-long'] = value * 0.0098
		returnDict['tf-short'] = value * 0.011
		returnDict['hN'] = value
		returnDict['J/m'] = value * 100.0
		returnDict['mN'] = value * 100000.0
	elif units == 'J/m':
		returnDict['daN'] = value * 0.1
		returnDict['dyn'] = value * 100000.0
		returnDict['gf'] = value * 101.97
		returnDict['kgf'] = value * 0.1
		returnDict['kN'] = value * 0.001
		returnDict['kip'] = value * 0.000225
		returnDict['klbs'] = value * 0.000225
		returnDict['MN'] = value * 1e-06
		returnDict['N'] = value
		returnDict['ozf'] = value * 3.6
		returnDict['lbf'] = value * 0.22
		returnDict['pdl'] = value * 7.23
		returnDict['sn'] = value * 0.001
		returnDict['tf-metric'] = value * 0.000102
		returnDict['tf-long'] = value * 0.0001
		returnDict['tf-short'] = value * 0.000112
		returnDict['hN'] = value * 0.01
		returnDict['J/m'] = value
		returnDict['mN'] = value * 1000.0
	elif units == 'mN':
		returnDict['daN'] = value * 0.0001
		returnDict['dyn'] = value * 100.0
		returnDict['gf'] = value * 0.1
		returnDict['kgf'] = value * 0.0001
		returnDict['kN'] = value * 9.81e-07
		returnDict['kip'] = value * 2.21e-07
		returnDict['klbs'] = value * 2.21e-07
		returnDict['MN'] = value * 9.83e-10
		returnDict['N'] = value * 0.00098
		returnDict['ozf'] = value * 0.00353
		returnDict['lbf'] = value * 0.000221
		returnDict['pdl'] = value * 0.01
		returnDict['sn'] = value * 1.38e-06
		returnDict['tf-metric'] = value * 1.41e-07
		returnDict['tf-long'] = value * 1.39e-07
		returnDict['tf-short'] = value * 1.56e-07
		returnDict['hN'] = value * 9.8e-06
		returnDict['J/m'] = value * 0.00098
		returnDict['mN'] = value
	return returnDict

def power(value, units):
	returnDict = {}
	if units == 'BTU/sec':
		returnDict['BTU/sec'] = value
		returnDict['BTU/min'] = value * 59.9999772
		returnDict['cal/min'] = value * 15116.064775
		returnDict['cal/sec'] = value * 251.9344129
		returnDict['ft-lb/min'] = value * 46678.8010423
		returnDict['ft-lb/sec'] = value * 777.9798223
		returnDict['hp'] = value * 1.4145088
		returnDict['hp-elec'] = value * 1.4139397
		returnDict['hp-met'] = value * 1.4341275
		returnDict['J/s'] = value * 1054.799
		returnDict['kcal/min'] = value * 15.1160648
		returnDict['kcal/s'] = value * 0.2519344
		returnDict['kg-m/min'] = value * 6453.5725342
		returnDict['kg-m/sec'] = value * 107.5595642
		returnDict['kW'] = value * 1.054799
		returnDict['MW'] = value * 0.0010548
		returnDict['N-m/s'] = value * 1054.799
		returnDict['ton-ref'] = value * 0.299927
		returnDict['var'] = value * 1054.799
		returnDict['W'] = value * 1054.799
	elif units == 'BTU/min':
		returnDict['BTU/sec'] = value * 0.0166667
		returnDict['BTU/min'] = value
		returnDict['cal/min'] = value * 251.9345085
		returnDict['cal/sec'] = value * 4.1989085
		returnDict['ft-lb/min'] = value * 777.9803124
		returnDict['ft-lb/sec'] = value * 12.9663353
		returnDict['hp'] = value * 0.0235752
		returnDict['hp-elec'] = value * 0.0235657
		returnDict['hp-met'] = value * 0.0239021
		returnDict['J/s'] = value * 17.57999
		returnDict['kcal/min'] = value * 0.2519345
		returnDict['kcal/s'] = value * 0.0041989
		returnDict['kg-m/min'] = value * 107.559583
		returnDict['kg-m/sec'] = value * 1.7926601
		returnDict['kW'] = value * 0.01758
		returnDict['MW'] = value * 1.76e-05
		returnDict['N-m/s'] = value * 17.57999
		returnDict['ton-ref'] = value * 0.0049988
		returnDict['var'] = value * 17.57999
		returnDict['W'] = value * 17.57999
	elif units == 'cal/min':
		returnDict['BTU/sec'] = value * 6.62e-05
		returnDict['BTU/min'] = value * 0.0039693
		returnDict['cal/min'] = value
		returnDict['cal/sec'] = value * 0.0166667
		returnDict['ft-lb/min'] = value * 3.088026
		returnDict['ft-lb/sec'] = value * 0.0514671
		returnDict['hp'] = value * 9.36e-05
		returnDict['hp-elec'] = value * 9.35e-05
		returnDict['hp-met'] = value * 9.49e-05
		returnDict['J/s'] = value * 0.06978
		returnDict['kcal/min'] = value * 0.001
		returnDict['kcal/s'] = value * 1.67e-05
		returnDict['kg-m/min'] = value * 0.4269347
		returnDict['kg-m/sec'] = value * 0.0071156
		returnDict['kW'] = value * 6.98e-05
		returnDict['MW'] = value * 6.98e-08
		returnDict['N-m/s'] = value * 0.06978
		returnDict['ton-ref'] = value * 1.98e-05
		returnDict['var'] = value * 0.06978
		returnDict['W'] = value * 0.06978
	elif units == 'cal/sec':
		returnDict['BTU/sec'] = value * 0.0039693
		returnDict['BTU/min'] = value * 0.2381571
		returnDict['cal/min'] = value * 60.0
		returnDict['cal/sec'] = value
		returnDict['ft-lb/min'] = value * 185.28156
		returnDict['ft-lb/sec'] = value * 3.0880252
		returnDict['hp'] = value * 0.0056146
		returnDict['hp-elec'] = value * 0.0056123
		returnDict['hp-met'] = value * 0.0056925
		returnDict['J/s'] = value * 4.1868
		returnDict['kcal/min'] = value * 0.06
		returnDict['kcal/s'] = value * 0.001
		returnDict['kg-m/min'] = value * 25.6160818
		returnDict['kg-m/sec'] = value * 0.4269348
		returnDict['kW'] = value * 0.0041868
		returnDict['MW'] = value * 4.2e-06
		returnDict['N-m/s'] = value * 4.1868
		returnDict['ton-ref'] = value * 0.0011905
		returnDict['var'] = value * 4.1868
		returnDict['W'] = value * 4.1868
	elif units == 'ft-lb/min':
		returnDict['BTU/sec'] = value * 2.14e-05
		returnDict['BTU/min'] = value * 0.0012854
		returnDict['cal/min'] = value * 0.3238315
		returnDict['cal/sec'] = value * 0.0053972
		returnDict['ft-lb/min'] = value
		returnDict['ft-lb/sec'] = value * 0.0166667
		returnDict['hp'] = value * 3.03e-05
		returnDict['hp-elec'] = value * 3.03e-05
		returnDict['hp-met'] = value * 3.07e-05
		returnDict['J/s'] = value * 0.022597
		returnDict['kcal/min'] = value * 0.0003238
		returnDict['kcal/s'] = value * 5.4e-06
		returnDict['kg-m/min'] = value * 0.1382549
		returnDict['kg-m/sec'] = value * 0.0023042
		returnDict['kW'] = value * 2.26e-05
		returnDict['MW'] = value * 2.26e-08
		returnDict['N-m/s'] = value * 0.022597
		returnDict['ton-ref'] = value * 6.4e-06
		returnDict['var'] = value * 0.022597
		returnDict['W'] = value * 0.022597
	elif units == 'ft-lb/sec':
		returnDict['BTU/sec'] = value * 0.0012854
		returnDict['BTU/min'] = value * 0.0771228
		returnDict['cal/min'] = value * 19.4298931
		returnDict['cal/sec'] = value * 0.3238316
		returnDict['ft-lb/min'] = value * 60.000015
		returnDict['ft-lb/sec'] = value
		returnDict['hp'] = value * 0.0018182
		returnDict['hp-elec'] = value * 0.0018175
		returnDict['hp-met'] = value * 0.0018434
		returnDict['J/s'] = value * 1.3558179
		returnDict['kcal/min'] = value * 0.0194299
		returnDict['kcal/s'] = value * 0.0003238
		returnDict['kg-m/min'] = value * 8.2952955
		returnDict['kg-m/sec'] = value * 0.138255
		returnDict['kW'] = value * 0.0013558
		returnDict['MW'] = value * 1.4e-06
		returnDict['N-m/s'] = value * 1.3558179
		returnDict['ton-ref'] = value * 0.0003855
		returnDict['var'] = value * 1.3558179
		returnDict['W'] = value * 1.3558179
	elif units == 'hp':
		returnDict['BTU/sec'] = value * 0.7069592
		returnDict['BTU/min'] = value * 42.4175366
		returnDict['cal/min'] = value * 10686.4412439
		returnDict['cal/sec'] = value * 178.1073541
		returnDict['ft-lb/min'] = value * 33000.0084082
		returnDict['ft-lb/sec'] = value * 550.0000022
		returnDict['hp'] = value
		returnDict['hp-elec'] = value * 0.9995977
		returnDict['hp-met'] = value * 1.0138697
		returnDict['J/s'] = value * 745.69987
		returnDict['kcal/min'] = value * 10.6864412
		returnDict['kcal/s'] = value * 0.1781074
		returnDict['kg-m/min'] = value * 4562.4125543
		returnDict['kg-m/sec'] = value * 76.0402247
		returnDict['kW'] = value * 0.7456999
		returnDict['MW'] = value * 0.0007457
		returnDict['N-m/s'] = value * 745.69987
		returnDict['ton-ref'] = value * 0.2120361
		returnDict['var'] = value * 745.69987
		returnDict['W'] = value * 745.69987
	elif units == 'hp-elec':
		returnDict['BTU/sec'] = value * 0.7072437
		returnDict['BTU/min'] = value * 42.4346089
		returnDict['cal/min'] = value * 10690.742333
		returnDict['cal/sec'] = value * 178.1790389
		returnDict['ft-lb/min'] = value * 33013.2902833
		returnDict['ft-lb/sec'] = value * 550.2213667
		returnDict['hp'] = value * 1.0004025
		returnDict['hp-elec'] = value
		returnDict['hp-met'] = value * 1.0142777
		returnDict['J/s'] = value * 746.0
		returnDict['kcal/min'] = value * 10.6907423
		returnDict['kcal/s'] = value * 0.178179
		returnDict['kg-m/min'] = value * 4564.2488384
		returnDict['kg-m/sec'] = value * 76.0708295
		returnDict['kW'] = value * 0.746
		returnDict['MW'] = value * 0.000746
		returnDict['N-m/s'] = value * 746.0
		returnDict['ton-ref'] = value * 0.2121215
		returnDict['var'] = value * 746.0
		returnDict['W'] = value * 746.0
	elif units == 'hp-met':
		returnDict['BTU/sec'] = value * 0.6972881
		returnDict['BTU/min'] = value * 41.8372678
		returnDict['cal/min'] = value * 10540.2515047
		returnDict['cal/sec'] = value * 175.6708584
		returnDict['ft-lb/min'] = value * 32548.5706927
		returnDict['ft-lb/sec'] = value * 542.4760422
		returnDict['hp'] = value * 0.9863201
		returnDict['hp-elec'] = value * 0.9859233
		returnDict['hp-met'] = value
		returnDict['J/s'] = value * 735.49875
		returnDict['kcal/min'] = value * 10.5402515
		returnDict['kcal/s'] = value * 0.1756709
		returnDict['kg-m/min'] = value * 4499.9990823
		returnDict['kg-m/sec'] = value * 75.0
		returnDict['kW'] = value * 0.7354987
		returnDict['MW'] = value * 0.0007355
		returnDict['N-m/s'] = value * 735.49875
		returnDict['ton-ref'] = value * 0.2091355
		returnDict['var'] = value * 735.49875
		returnDict['W'] = value * 735.49875
	elif units == 'J/s':
		returnDict['BTU/sec'] = value * 0.000948
		returnDict['BTU/min'] = value * 0.0568829
		returnDict['cal/min'] = value * 14.3307538
		returnDict['cal/sec'] = value * 0.2388459
		returnDict['ft-lb/min'] = value * 44.2537403
		returnDict['ft-lb/sec'] = value * 0.7375622
		returnDict['hp'] = value * 0.001341
		returnDict['hp-elec'] = value * 0.0013405
		returnDict['hp-met'] = value * 0.0013596
		returnDict['J/s'] = value
		returnDict['kcal/min'] = value * 0.0143308
		returnDict['kcal/s'] = value * 0.0002388
		returnDict['kg-m/min'] = value * 6.118296
		returnDict['kg-m/sec'] = value * 0.1019716
		returnDict['kW'] = value * 0.001
		returnDict['MW'] = value * 1e-06
		returnDict['N-m/s'] = value
		returnDict['ton-ref'] = value * 0.0002843
		returnDict['var'] = value
		returnDict['W'] = value
	elif units == 'kcal/min':
		returnDict['BTU/sec'] = value * 0.0661548
		returnDict['BTU/min'] = value * 3.9692855
		returnDict['cal/min'] = value * 1000.0
		returnDict['cal/sec'] = value * 16.6666667
		returnDict['ft-lb/min'] = value * 3088.026
		returnDict['ft-lb/sec'] = value * 51.4670871
		returnDict['hp'] = value * 0.0935765
		returnDict['hp-elec'] = value * 0.0935389
		returnDict['hp-met'] = value * 0.0948744
		returnDict['J/s'] = value * 69.78
		returnDict['kcal/min'] = value
		returnDict['kcal/s'] = value * 0.0166667
		returnDict['kg-m/min'] = value * 426.934697
		returnDict['kg-m/sec'] = value * 7.1155797
		returnDict['kW'] = value * 0.06978
		returnDict['MW'] = value * 6.98e-05
		returnDict['N-m/s'] = value * 69.78
		returnDict['ton-ref'] = value * 0.0198416
		returnDict['var'] = value * 69.78
		returnDict['W'] = value * 69.78
	elif units == 'kcal/s':
		returnDict['BTU/sec'] = value * 3.969287
		returnDict['BTU/min'] = value * 238.1571321
		returnDict['cal/min'] = value * 60000.0
		returnDict['cal/sec'] = value * 1000.0
		returnDict['ft-lb/min'] = value * 185281.5599975
		returnDict['ft-lb/sec'] = value * 3088.0252256
		returnDict['hp'] = value * 5.6145913
		returnDict['hp-elec'] = value * 5.6123324
		returnDict['hp-met'] = value * 5.6924638
		returnDict['J/s'] = value * 4186.8
		returnDict['kcal/min'] = value * 60.0
		returnDict['kcal/s'] = value
		returnDict['kg-m/min'] = value * 25616.0818187
		returnDict['kg-m/sec'] = value * 426.934784
		returnDict['kW'] = value * 4.1868
		returnDict['MW'] = value * 0.0041868
		returnDict['N-m/s'] = value * 4186.8
		returnDict['ton-ref'] = value * 1.1904962
		returnDict['var'] = value * 4186.8
		returnDict['W'] = value * 4186.8
	elif units == 'kg-m/min':
		returnDict['BTU/sec'] = value * 0.000155
		returnDict['BTU/min'] = value * 0.0092972
		returnDict['cal/min'] = value * 2.3422786
		returnDict['cal/sec'] = value * 0.039038
		returnDict['ft-lb/min'] = value * 7.2330172
		returnDict['ft-lb/sec'] = value * 0.1205503
		returnDict['hp'] = value * 0.0002192
		returnDict['hp-elec'] = value * 0.0002191
		returnDict['hp-met'] = value * 0.0002222
		returnDict['J/s'] = value * 0.1634442
		returnDict['kcal/min'] = value * 0.0023423
		returnDict['kcal/s'] = value * 3.9e-05
		returnDict['kg-m/min'] = value
		returnDict['kg-m/sec'] = value * 0.0166667
		returnDict['kW'] = value * 0.0001634
		returnDict['MW'] = value * 1.634e-07
		returnDict['N-m/s'] = value * 0.1634442
		returnDict['ton-ref'] = value * 4.65e-05
		returnDict['var'] = value * 0.1634442
		returnDict['W'] = value * 0.1634442
	elif units == 'kg-m/sec':
		returnDict['BTU/sec'] = value * 0.0092972
		returnDict['BTU/min'] = value * 0.5578302
		returnDict['cal/min'] = value * 140.5366867
		returnDict['cal/sec'] = value * 2.3422781
		returnDict['ft-lb/min'] = value * 433.9809426
		returnDict['ft-lb/sec'] = value * 7.2330139
		returnDict['hp'] = value * 0.0131509
		returnDict['hp-elec'] = value * 0.0131456
		returnDict['hp-met'] = value * 0.0133333
		returnDict['J/s'] = value * 9.80665
		returnDict['kcal/min'] = value * 0.1405367
		returnDict['kcal/s'] = value * 0.0023423
		returnDict['kg-m/min'] = value * 59.9999878
		returnDict['kg-m/sec'] = value
		returnDict['kW'] = value * 0.0098067
		returnDict['MW'] = value * 9.8e-06
		returnDict['N-m/s'] = value * 9.80665
		returnDict['ton-ref'] = value * 0.0027885
		returnDict['var'] = value * 9.80665
		returnDict['W'] = value * 9.80665
	elif units == 'kW':
		returnDict['BTU/sec'] = value * 0.9480479
		returnDict['BTU/min'] = value * 56.8828537
		returnDict['cal/min'] = value * 14330.7537976
		returnDict['cal/sec'] = value * 238.8458966
		returnDict['ft-lb/min'] = value * 44253.7403261
		returnDict['ft-lb/sec'] = value * 737.5621538
		returnDict['hp'] = value * 1.3410221
		returnDict['hp-elec'] = value * 1.3404826
		returnDict['hp-met'] = value * 1.3596216
		returnDict['J/s'] = value * 1000.0
		returnDict['kcal/min'] = value * 14.3307538
		returnDict['kcal/s'] = value * 0.2388459
		returnDict['kg-m/min'] = value * 6118.2960301
		returnDict['kg-m/sec'] = value * 101.9716213
		returnDict['kW'] = value
		returnDict['MW'] = value * 0.001
		returnDict['N-m/s'] = value * 1000.0
		returnDict['ton-ref'] = value * 0.2843451
		returnDict['var'] = value * 1000.0
		returnDict['W'] = value * 1000.0
	elif units == 'MW':
		returnDict['BTU/sec'] = value * 948.0479219
		returnDict['BTU/min'] = value * 56882.8537445
		returnDict['cal/min'] = value * 14330753.7976498
		returnDict['cal/sec'] = value * 238845.8966275
		returnDict['ft-lb/min'] = value * 44253740.3261324
		returnDict['ft-lb/sec'] = value * 737562.1538095
		returnDict['hp'] = value * 1341.0220924
		returnDict['hp-elec'] = value * 1340.4825737
		returnDict['hp-met'] = value * 1359.6216173
		returnDict['J/s'] = value * 1000000.0
		returnDict['kcal/min'] = value * 14330.7537976
		returnDict['kcal/s'] = value * 238.8458966
		returnDict['kg-m/min'] = value * 6118296.0300824
		returnDict['kg-m/sec'] = value * 101971.6212978
		returnDict['kW'] = value * 1000.0
		returnDict['MW'] = value
		returnDict['N-m/s'] = value * 1000000.0
		returnDict['ton-ref'] = value * 284.3451363
		returnDict['var'] = value * 1000000.0
		returnDict['W'] = value * 1000000.0
	elif units == 'N-m/s':
		returnDict['BTU/sec'] = value * 0.000948
		returnDict['BTU/min'] = value * 0.0568829
		returnDict['cal/min'] = value * 14.3307538
		returnDict['cal/sec'] = value * 0.2388459
		returnDict['ft-lb/min'] = value * 44.2537403
		returnDict['ft-lb/sec'] = value * 0.7375622
		returnDict['hp'] = value * 0.001341
		returnDict['hp-elec'] = value * 0.0013405
		returnDict['hp-met'] = value * 0.0013596
		returnDict['J/s'] = value
		returnDict['kcal/min'] = value * 0.0143308
		returnDict['kcal/s'] = value * 0.0002388
		returnDict['kg-m/min'] = value * 6.118296
		returnDict['kg-m/sec'] = value * 0.1019716
		returnDict['kW'] = value * 0.001
		returnDict['MW'] = value * 1e-06
		returnDict['N-m/s'] = value
		returnDict['ton-ref'] = value * 0.0002843
		returnDict['var'] = value
		returnDict['W'] = value
	elif units == 'ton-ref':
		returnDict['BTU/sec'] = value * 3.334145
		returnDict['BTU/min'] = value * 200.0486257
		returnDict['cal/min'] = value * 50399.1521926
		returnDict['cal/sec'] = value * 839.9858699
		returnDict['ft-lb/min'] = value * 155633.8923466
		returnDict['ft-lb/sec'] = value * 2593.8975553
		returnDict['hp'] = value * 4.7161774
		returnDict['hp-elec'] = value * 4.7142799
		returnDict['hp-met'] = value * 4.7815891
		returnDict['J/s'] = value * 3516.85284
		returnDict['kcal/min'] = value * 50.3991522
		returnDict['kcal/s'] = value * 0.8399859
		returnDict['kg-m/min'] = value * 21517.1467694
		returnDict['kg-m/sec'] = value * 358.619186
		returnDict['kW'] = value * 3.5168528
		returnDict['MW'] = value * 0.0035169
		returnDict['N-m/s'] = value * 3516.85284
		returnDict['ton-ref'] = value
		returnDict['var'] = value * 3516.85284
		returnDict['W'] = value * 3516.85284
	elif units == 'var':
		returnDict['BTU/sec'] = value * 0.000948
		returnDict['BTU/min'] = value * 0.0568829
		returnDict['cal/min'] = value * 14.3307538
		returnDict['cal/sec'] = value * 0.2388459
		returnDict['ft-lb/min'] = value * 44.2537403
		returnDict['ft-lb/sec'] = value * 0.7375622
		returnDict['hp'] = value * 0.001341
		returnDict['hp-elec'] = value * 0.0013405
		returnDict['hp-met'] = value * 0.0013596
		returnDict['J/s'] = value
		returnDict['kcal/min'] = value * 0.0143308
		returnDict['kcal/s'] = value * 0.0002388
		returnDict['kg-m/min'] = value * 6.118296
		returnDict['kg-m/sec'] = value * 0.1019716
		returnDict['kW'] = value * 0.001
		returnDict['MW'] = value * 1e-06
		returnDict['N-m/s'] = value
		returnDict['ton-ref'] = value * 0.0002843
		returnDict['var'] = value
		returnDict['W'] = value
	elif units == 'W':
		returnDict['BTU/sec'] = value * 0.000948
		returnDict['BTU/min'] = value * 0.0568829
		returnDict['cal/min'] = value * 14.3307538
		returnDict['cal/sec'] = value * 0.2388459
		returnDict['ft-lb/min'] = value * 44.2537403
		returnDict['ft-lb/sec'] = value * 0.7375622
		returnDict['hp'] = value * 0.001341
		returnDict['hp-elec'] = value * 0.0013405
		returnDict['hp-met'] = value * 0.0013596
		returnDict['J/s'] = value
		returnDict['kcal/min'] = value * 0.0143308
		returnDict['kcal/s'] = value * 0.0002388
		returnDict['kg-m/min'] = value * 6.118296
		returnDict['kg-m/sec'] = value * 0.1019716
		returnDict['kW'] = value * 0.001
		returnDict['MW'] = value * 1e-06
		returnDict['N-m/s'] = value
		returnDict['ton-ref'] = value * 0.0002843
		returnDict['var'] = value
		returnDict['W'] = value
	return returnDict

def velocity(value, units):
	returnDict = {}
	if units == 'ft/d':
		returnDict['ft/d'] = value
		returnDict['ft/hr'] = value * 0.0416667
		returnDict['ft/min'] = value * 0.0006944
		returnDict['ft/s'] = value * 1.16e-05
		returnDict['kph'] = value * 1.27e-05
		returnDict['k/min'] = value * 2.116e-07
		returnDict['k/sec'] = value * 3.528e-09
		returnDict['knot'] = value * 6.9e-06
		returnDict['mach'] = value * 1.0366974e-08
		returnDict['m/d'] = value * 0.3048
		returnDict['m/hr'] = value * 0.0127
		returnDict['m/min'] = value * 0.0002117
		returnDict['m/sec'] = value * 3.5e-06
		returnDict['mph'] = value * 7.9e-06
		returnDict['mi/min'] = value * 1.317e-07
		returnDict['mi/sec'] = value * 2.194e-09
	elif units == 'ft/hr':
		returnDict['ft/d'] = value * 24.0
		returnDict['ft/hr'] = value
		returnDict['ft/min'] = value * 0.0166667
		returnDict['ft/s'] = value * 0.0002778
		returnDict['kph'] = value * 0.0003048
		returnDict['k/min'] = value * 5.1e-06
		returnDict['k/sec'] = value * 8.5e-08
		returnDict['knot'] = value * 0.0001646
		returnDict['mach'] = value * 2.4833e-07
		returnDict['m/d'] = value * 7.3152
		returnDict['m/hr'] = value * 0.3048
		returnDict['m/min'] = value * 0.00508
		returnDict['m/sec'] = value * 8.47e-05
		returnDict['mph'] = value * 0.0001894
		returnDict['mi/min'] = value * 3.2e-06
		returnDict['mi/sec'] = value * 5.33e-08
	elif units == 'ft/min':
		returnDict['ft/d'] = value * 1440.0
		returnDict['ft/hr'] = value * 60.0
		returnDict['ft/min'] = value
		returnDict['ft/s'] = value * 0.0166667
		returnDict['kph'] = value * 0.0166667
		returnDict['k/min'] = value * 0.0003048
		returnDict['k/sec'] = value * 5.1e-06
		returnDict['knot'] = value * 0.0098747
		returnDict['mach'] = value * 1.49e-05
		returnDict['m/d'] = value * 438.912
		returnDict['m/hr'] = value * 438.912
		returnDict['m/min'] = value * 0.3048
		returnDict['m/sec'] = value * 0.00508
		returnDict['mph'] = value * 0.0113636
		returnDict['mi/min'] = value * 0.0001894
		returnDict['mi/sec'] = value * 3.2e-06
	elif units == 'ft/s':
		returnDict['ft/d'] = value * 86400.0
		returnDict['ft/hr'] = value * 3600.0
		returnDict['ft/min'] = value * 60.0
		returnDict['ft/s'] = value
		returnDict['kph'] = value * 1.09728
		returnDict['k/min'] = value * 0.018288
		returnDict['k/sec'] = value * 0.0003048
		returnDict['knot'] = value * 0.5924838
		returnDict['mach'] = value * 0.0008957
		returnDict['m/d'] = value * 26334.72
		returnDict['m/hr'] = value * 1097.28
		returnDict['m/min'] = value * 18.288
		returnDict['m/sec'] = value * 0.3048
		returnDict['mph'] = value * 0.6818182
		returnDict['mi/min'] = value * 0.0113636
		returnDict['mi/sec'] = value * 0.0001894
	elif units == 'kph':
		returnDict['ft/d'] = value * 78740.1574803
		returnDict['ft/hr'] = value * 3280.839895
		returnDict['ft/min'] = value * 54.6806649
		returnDict['ft/s'] = value * 0.9113444
		returnDict['kph'] = value
		returnDict['k/min'] = value * 0.0166667
		returnDict['k/sec'] = value * 0.0002778
		returnDict['knot'] = value * 0.5399568
		returnDict['mach'] = value * 0.0008163
		returnDict['m/d'] = value * 24000.0
		returnDict['m/hr'] = value * 1000.0
		returnDict['m/min'] = value * 16.6666667
		returnDict['m/sec'] = value * 0.2777778
		returnDict['mph'] = value * 0.6213712
		returnDict['mi/min'] = value * 0.0103562
		returnDict['mi/sec'] = value * 0.0001726
	elif units == 'k/min':
		returnDict['ft/d'] = value * 4724409.4488189
		returnDict['ft/hr'] = value * 196850.3937008
		returnDict['ft/min'] = value * 3280.839895
		returnDict['ft/s'] = value * 54.6806649
		returnDict['kph'] = value * 60.0
		returnDict['k/min'] = value
		returnDict['k/sec'] = value * 0.0166667
		returnDict['knot'] = value * 32.3974082
		returnDict['mach'] = value * 0.0489778
		returnDict['m/d'] = value * 1440000.0
		returnDict['m/hr'] = value * 60000.0
		returnDict['m/min'] = value * 1000.0
		returnDict['m/sec'] = value * 16.6666667
		returnDict['mph'] = value * 37.2822715
		returnDict['mi/min'] = value * 0.6213712
		returnDict['mi/sec'] = value * 0.0103562
	elif units == 'k/sec':
		returnDict['ft/d'] = value * 283464566.929133
		returnDict['ft/hr'] = value * 11811023.6220472
		returnDict['ft/min'] = value * 196850.3937008
		returnDict['ft/s'] = value * 3280.839895
		returnDict['kph'] = value * 3600.0
		returnDict['k/min'] = value * 60.0
		returnDict['k/sec'] = value
		returnDict['knot'] = value * 1943.8444924
		returnDict['mach'] = value * 2.93867
		returnDict['m/d'] = value * 86400000.0
		returnDict['m/hr'] = value * 3600000.0
		returnDict['m/min'] = value * 60000.0
		returnDict['m/sec'] = value * 1000.0
		returnDict['mph'] = value * 2236.9362921
		returnDict['mi/min'] = value * 37.2822715
		returnDict['mi/sec'] = value * 0.6213712
	elif units == 'knot':
		returnDict['ft/d'] = value * 145826.7716535
		returnDict['ft/hr'] = value * 6076.1154856
		returnDict['ft/min'] = value * 101.2685914
		returnDict['ft/s'] = value * 1.6878099
		returnDict['kph'] = value * 1.852
		returnDict['k/min'] = value * 0.0308667
		returnDict['k/sec'] = value * 0.0005144
		returnDict['knot'] = value
		returnDict['mach'] = value * 0.0015118
		returnDict['m/d'] = value * 44448.0
		returnDict['m/hr'] = value * 1852.0
		returnDict['m/min'] = value * 30.8666667
		returnDict['m/sec'] = value * 0.5144444
		returnDict['mph'] = value * 1.1507794
		returnDict['mi/min'] = value * 0.0191797
		returnDict['mi/sec'] = value * 0.0003197
	elif units == 'mach':
		returnDict['ft/d'] = value * 96460157.480315
		returnDict['ft/hr'] = value * 4019173.2283465
		returnDict['ft/min'] = value * 66986.2204724
		returnDict['ft/s'] = value * 1116.4370079
		returnDict['kph'] = value * 1225.044
		returnDict['k/min'] = value * 20.4174
		returnDict['k/sec'] = value * 0.34029
		returnDict['knot'] = value * 661.4708423
		returnDict['mach'] = value
		returnDict['m/d'] = value * 29401056.0
		returnDict['m/hr'] = value * 1225044.0
		returnDict['m/min'] = value * 20417.4
		returnDict['m/sec'] = value * 340.29
		returnDict['mph'] = value * 761.2070508
		returnDict['mi/min'] = value * 12.6867842
		returnDict['mi/sec'] = value * 0.2114464
	elif units == 'm/d':
		returnDict['ft/d'] = value * 3.2808399
		returnDict['ft/hr'] = value * 0.1367017
		returnDict['ft/min'] = value * 0.0022784
		returnDict['ft/s'] = value * 3.8e-05
		returnDict['kph'] = value * 4.17e-05
		returnDict['k/min'] = value * 6.95e-07
		returnDict['k/sec'] = value * 1.158e-08
		returnDict['knot'] = value * 2.25e-05
		returnDict['mach'] = value * 3.40124e-08
		returnDict['m/d'] = value
		returnDict['m/hr'] = value * 0.0416667
		returnDict['m/min'] = value * 0.0006944
		returnDict['m/sec'] = value * 1.16e-05
		returnDict['mph'] = value * 2.59e-05
		returnDict['mi/min'] = value * 4.317e-07
		returnDict['mi/sec'] = value * 7.194e-09
	elif units == 'm/hr':
		returnDict['ft/d'] = value * 78.7401575
		returnDict['ft/hr'] = value * 3.2808399
		returnDict['ft/min'] = value * 0.0546807
		returnDict['ft/s'] = value * 0.0009113
		returnDict['kph'] = value * 0.001
		returnDict['k/min'] = value * 1.67e-05
		returnDict['k/sec'] = value * 2.7833e-07
		returnDict['knot'] = value * 0.00054
		returnDict['mach'] = value * 8.162976e-07
		returnDict['m/d'] = value * 24.0
		returnDict['m/hr'] = value
		returnDict['m/min'] = value * 0.0166667
		returnDict['m/sec'] = value * 0.0002778
		returnDict['mph'] = value * 0.0006214
		returnDict['mi/min'] = value * 1.04e-05
		returnDict['mi/sec'] = value * 1.733e-07
	elif units == 'm/min':
		returnDict['ft/d'] = value * 4724.4094488
		returnDict['ft/hr'] = value * 196.8503937
		returnDict['ft/min'] = value * 3.2808399
		returnDict['ft/s'] = value * 0.0546807
		returnDict['kph'] = value * 0.06
		returnDict['k/min'] = value * 0.001
		returnDict['k/sec'] = value * 1.67e-05
		returnDict['knot'] = value * 0.0323974
		returnDict['mach'] = value * 4.9e-05
		returnDict['m/d'] = value * 1440.0
		returnDict['m/hr'] = value * 60.0
		returnDict['m/min'] = value
		returnDict['m/sec'] = value * 0.0166667
		returnDict['mph'] = value * 0.0372823
		returnDict['mi/min'] = value * 0.0006214
		returnDict['mi/sec'] = value * 1.04e-05
	elif units == 'm/sec':
		returnDict['ft/d'] = value * 283464.5669291
		returnDict['ft/hr'] = value * 11811.023622
		returnDict['ft/min'] = value * 196.8503937
		returnDict['ft/s'] = value * 3.2808399
		returnDict['kph'] = value * 3.6
		returnDict['k/min'] = value * 0.06
		returnDict['k/sec'] = value * 0.001
		returnDict['knot'] = value * 1.9438445
		returnDict['mach'] = value * 0.0029387
		returnDict['m/d'] = value * 86400.0
		returnDict['m/hr'] = value * 3600.0
		returnDict['m/min'] = value * 60.0
		returnDict['m/sec'] = value
		returnDict['mph'] = value * 2.2369363
		returnDict['mi/min'] = value * 0.0372823
		returnDict['mi/sec'] = value * 0.0006214
	elif units == 'mph':
		returnDict['ft/d'] = value * 126720.0
		returnDict['ft/hr'] = value * 5280.0
		returnDict['ft/min'] = value * 88.0
		returnDict['ft/s'] = value * 1.4666667
		returnDict['kph'] = value * 1.609344
		returnDict['k/min'] = value * 0.0268224
		returnDict['k/sec'] = value * 0.000447
		returnDict['knot'] = value * 0.8689762
		returnDict['mach'] = value * 0.0013137
		returnDict['m/d'] = value * 38624.256
		returnDict['m/hr'] = value * 1609.344
		returnDict['m/min'] = value * 26.8224
		returnDict['m/sec'] = value * 0.44704
		returnDict['mph'] = value
		returnDict['mi/min'] = value * 0.0166667
		returnDict['mi/sec'] = value * 0.0002778
	elif units == 'mi/min':
		returnDict['ft/d'] = value * 7603200.0
		returnDict['ft/hr'] = value * 316800.0
		returnDict['ft/min'] = value * 5280.0
		returnDict['ft/s'] = value * 88.0
		returnDict['kph'] = value * 96.56064
		returnDict['k/min'] = value * 1.609344
		returnDict['k/sec'] = value * 0.0268224
		returnDict['knot'] = value * 52.1385745
		returnDict['mach'] = value * 0.0788222
		returnDict['m/d'] = value * 2317455.36
		returnDict['m/hr'] = value * 96560.64
		returnDict['m/min'] = value * 1609.344
		returnDict['m/sec'] = value * 26.8224
		returnDict['mph'] = value * 60.0
		returnDict['mi/min'] = value
		returnDict['mi/sec'] = value * 0.0166667
	elif units == 'mi/sec':
		returnDict['ft/d'] = value * 456191999.999999
		returnDict['ft/hr'] = value * 19008000.0
		returnDict['ft/min'] = value * 316800.0
		returnDict['ft/s'] = value * 5280.0
		returnDict['kph'] = value * 5793.6384
		returnDict['k/min'] = value * 96.56064
		returnDict['k/sec'] = value * 1.609344
		returnDict['knot'] = value * 3128.3144708
		returnDict['mach'] = value * 4.7293309
		returnDict['m/d'] = value * 139047321.6
		returnDict['m/hr'] = value * 5793638.4
		returnDict['m/min'] = value * 96560.64
		returnDict['m/sec'] = value * 1609.344
		returnDict['mph'] = value * 3600.0
		returnDict['mi/min'] = value * 60.0
		returnDict['mi/sec'] = value
	return returnDict


def gas_injection_rate(value, units):
	returnDict = {}
	if units == 'm3/min':
		returnDict['m3/min'] = value
		returnDict['scfm'] = value * 35.335689
	elif units == 'scfm':
		returnDict['m3/min'] = value * 0.0283
		returnDict['scfm'] = value
	return returnDict

def gas_production_index(value, units):
	returnDict = {}
	if units == 'm3/d-MPa':
		returnDict['m3/d-MPa'] = value
		returnDict['m3/d-kPa'] = value * 1000.0
		returnDict['m3/hr-kPa'] = value * 41.6675544
		returnDict['MMSCFD/psi'] = value * 0.2436699
		returnDict['MSCF/hr-psi'] = value * 10.152921
		returnDict['MSCFD/psi'] = value * 243.6699
		returnDict['SCF/hr-psi'] = value * 10152.9209608
		returnDict['SCFD/psi'] = value * 243669.9
	elif units == 'm3/d-kPa':
		returnDict['m3/d-MPa'] = value * 0.001
		returnDict['m3/d-kPa'] = value
		returnDict['m3/hr-kPa'] = value * 0.0416676
		returnDict['MMSCFD/psi'] = value * 0.0002437
		returnDict['MSCF/hr-psi'] = value * 0.0101529
		returnDict['MSCFD/psi'] = value * 0.2436699
		returnDict['SCF/hr-psi'] = value * 10.152921
		returnDict['SCFD/psi'] = value * 243.6699
	elif units == 'm3/hr-kPa':
		returnDict['m3/d-MPa'] = value * 0.0239995
		returnDict['m3/d-kPa'] = value * 23.9994887
		returnDict['m3/hr-kPa'] = value
		returnDict['MMSCFD/psi'] = value * 0.005848
		returnDict['MSCF/hr-psi'] = value * 0.2436649
		returnDict['MSCFD/psi'] = value * 5.847953
		returnDict['SCF/hr-psi'] = value * 243.6649114
		returnDict['SCFD/psi'] = value * 5847.953
	elif units == 'MMSCFD/psi':
		returnDict['m3/d-MPa'] = value * 4.1039127
		returnDict['m3/d-kPa'] = value * 4103.9127114
		returnDict['m3/hr-kPa'] = value * 171.0000063
		returnDict['MMSCFD/psi'] = value
		returnDict['MSCF/hr-psi'] = value * 41.6667014
		returnDict['MSCFD/psi'] = value * 1000.0
		returnDict['SCF/hr-psi'] = value * 41666.7013889
		returnDict['SCFD/psi'] = value * 1000000.0
	elif units == 'MSCF/hr-psi':
		returnDict['m3/d-MPa'] = value * 0.0984938
		returnDict['m3/d-kPa'] = value * 98.493823
		returnDict['m3/hr-kPa'] = value * 4.1039967
		returnDict['MMSCFD/psi'] = value * 0.024
		returnDict['MSCF/hr-psi'] = value
		returnDict['MSCFD/psi'] = value * 24.0
		returnDict['SCF/hr-psi'] = value * 1000.0
		returnDict['SCFD/psi'] = value * 24000.0
	elif units == 'MSCFD/psi':
		returnDict['m3/d-MPa'] = value * 0.0041039
		returnDict['m3/d-kPa'] = value * 4.1039127
		returnDict['m3/hr-kPa'] = value * 0.171
		returnDict['MMSCFD/psi'] = value * 0.001
		returnDict['MSCF/hr-psi'] = value * 0.0416667
		returnDict['MSCFD/psi'] = value
		returnDict['SCF/hr-psi'] = value * 41.6667014
		returnDict['SCFD/psi'] = value * 1000.0
	elif units == 'SCF/hr-psi':
		returnDict['m3/d-MPa'] = value * 9.85e-05
		returnDict['m3/d-kPa'] = value * 0.0984938
		returnDict['m3/hr-kPa'] = value * 0.004104
		returnDict['MMSCFD/psi'] = value * 2.4e-05
		returnDict['MSCF/hr-psi'] = value * 0.001
		returnDict['MSCFD/psi'] = value * 0.024
		returnDict['SCF/hr-psi'] = value
		returnDict['SCFD/psi'] = value * 24.0
	elif units == 'SCFD/psi':
		returnDict['m3/d-MPa'] = value * 4.1e-06
		returnDict['m3/d-kPa'] = value * 0.0041039
		returnDict['m3/hr-kPa'] = value * 0.000171
		returnDict['MMSCFD/psi'] = value * 1e-06
		returnDict['MSCF/hr-psi'] = value * 4.17e-05
		returnDict['MSCFD/psi'] = value * 0.001
		returnDict['SCF/hr-psi'] = value * 0.0416667
		returnDict['SCFD/psi'] = value
	return returnDict

def gas_production_rate(value, units):
	returnDict = {}
	if units == 'm3/min':
		returnDict['m3/min'] = value 
		returnDict['MM'] = value * 0.0508834
		returnDict['MMM3/d'] = value * 0.00144
		returnDict['scfm'] = value * 35.3144754
	elif units == 'MM':
		returnDict['m3/min'] = value * 19.65278
		returnDict['MM'] = value 
		returnDict['MMM3/d'] = value * 0.0283
		returnDict['scfm'] = value * 694.0276159
	elif units == 'MMM3/d':
		returnDict['m3/min'] = value * 694.4445
		returnDict['MM'] = value * 35.3356879
		returnDict['MMM3/d'] = value 
		returnDict['scfm'] = value * 24523.9432143
	elif units == 'scfm':
		returnDict['m3/min'] = value * 0.028317
		returnDict['MM'] = value * 0.0014409
		returnDict['MMM3/d'] = value * 4.08e-05
		returnDict['scfm'] = value 
	return returnDict

def gas_volume(value, units):
	returnDict = {}
	if units == 'bbl':
		returnDict['bbl'] = value
		returnDict['cm3'] = value * 158987.2949285
		returnDict['dm3'] = value * 1589.8729493
		returnDict['ft3'] = value * 5.6145833
		returnDict['in3'] = value * 9702.0
		returnDict['m3'] = value * 0.1589873
		returnDict['yd3'] = value * 0.2079475
		returnDict['fl oz'] = value * 5376.0
		returnDict['gal'] = value * 42.0
		returnDict['L'] = value * 158.9872949
		returnDict['qt'] = value * 168.0
	elif units == 'cm3':
		returnDict['bbl'] = value * 6.3e-06
		returnDict['cm3'] = value
		returnDict['dm3'] = value * 0.01
		returnDict['ft3'] = value * 3.53e-05
		returnDict['in3'] = value * 0.0610237
		returnDict['m3'] = value * 1e-06
		returnDict['yd3'] = value * 1.3e-06
		returnDict['fl oz'] = value * 0.033814
		returnDict['gal'] = value * 0.0002642
		returnDict['L'] = value * 0.001
		returnDict['qt'] = value * 0.0010567
	elif units == 'dm3':
		returnDict['bbl'] = value * 0.000629
		returnDict['cm3'] = value * 100.0
		returnDict['dm3'] = value
		returnDict['ft3'] = value * 0.0035315
		returnDict['in3'] = value * 6.1023744
		returnDict['m3'] = value * 0.0001
		returnDict['yd3'] = value * 0.0001308
		returnDict['fl oz'] = value * 3.3814023
		returnDict['gal'] = value * 0.0264172
		returnDict['L'] = value * 0.1
		returnDict['qt'] = value * 0.1056688
	elif units == 'ft3':
		returnDict['bbl'] = value * 0.1781076
		returnDict['cm3'] = value * 28316.846592
		returnDict['dm3'] = value * 283.1684659
		returnDict['ft3'] = value
		returnDict['in3'] = value * 1728.0
		returnDict['m3'] = value * 0.0283168
		returnDict['yd3'] = value * 0.037037
		returnDict['fl oz'] = value * 957.5064935
		returnDict['gal'] = value * 7.4805195
		returnDict['L'] = value * 28.3168466
		returnDict['qt'] = value * 29.9220779
	elif units == 'in3':
		returnDict['bbl'] = value * 0.0001031
		returnDict['cm3'] = value * 16.387064
		returnDict['dm3'] = value * 0.1638706
		returnDict['ft3'] = value * 0.0005787
		returnDict['in3'] = value
		returnDict['m3'] = value * 1.64e-05
		returnDict['yd3'] = value * 2.14e-05
		returnDict['fl oz'] = value * 0.5541126
		returnDict['gal'] = value * 0.004329
		returnDict['L'] = value * 0.0163871
		returnDict['qt'] = value * 0.017316
	elif units == 'm3':
		returnDict['bbl'] = value * 6.2898108
		returnDict['cm3'] = value * 1000000.0
		returnDict['dm3'] = value * 10000.0
		returnDict['ft3'] = value * 35.3146667
		returnDict['in3'] = value * 61023.7440947
		returnDict['m3'] = value
		returnDict['yd3'] = value * 1.3079506
		returnDict['fl oz'] = value * 33814.0227017
		returnDict['gal'] = value * 264.1720524
		returnDict['L'] = value * 1000.0
		returnDict['qt'] = value * 1056.6882094
	elif units == 'yd3':
		returnDict['bbl'] = value * 4.8089054
		returnDict['cm3'] = value * 764554.857984
		returnDict['dm3'] = value * 7645.5485798
		returnDict['ft3'] = value * 27.0
		returnDict['in3'] = value * 46656.0
		returnDict['m3'] = value * 0.7645549
		returnDict['yd3'] = value
		returnDict['fl oz'] = value * 25852.6753246
		returnDict['gal'] = value * 201.974026
		returnDict['L'] = value * 764.554858
		returnDict['qt'] = value * 807.8961039
	elif units == 'fl oz':
		returnDict['bbl'] = value * 0.000186
		returnDict['cm3'] = value * 29.5735296
		returnDict['dm3'] = value * 0.2957353
		returnDict['ft3'] = value * 0.0010444
		returnDict['in3'] = value * 1.8046875
		returnDict['m3'] = value * 2.96e-05
		returnDict['yd3'] = value * 3.87e-05
		returnDict['fl oz'] = value
		returnDict['gal'] = value * 0.0078125
		returnDict['L'] = value * 0.0295735
		returnDict['qt'] = value * 0.03125
	elif units == ' gal':
		returnDict['bbl'] = value * 0.0238095
		returnDict['cm3'] = value * 3785.411784
		returnDict['dm3'] = value * 37.8541178
		returnDict['ft3'] = value * 0.1336806
		returnDict['in3'] = value * 231.0
		returnDict['m3'] = value * 0.0037854
		returnDict['yd3'] = value * 0.0049511
		returnDict['fl oz'] = value * 128.0
		returnDict['gal'] = value
		returnDict['L'] = value * 3.7854118
		returnDict['qt'] = value * 4.0
	elif units == 'L':
		returnDict['bbl'] = value * 0.0062898
		returnDict['cm3'] = value * 1000.0
		returnDict['dm3'] = value * 10.0
		returnDict['ft3'] = value * 0.0353147
		returnDict['in3'] = value * 61.0237441
		returnDict['m3'] = value * 0.001
		returnDict['yd3'] = value * 0.001308
		returnDict['fl oz'] = value * 33.8140227
		returnDict['gal'] = value * 0.2641721
		returnDict['L'] = value
		returnDict['qt'] = value * 1.0566882
	elif units == 'qt':
		returnDict['bbl'] = value * 0.0059524
		returnDict['cm3'] = value * 946.352946
		returnDict['dm3'] = value * 9.4635295
		returnDict['ft3'] = value * 0.0334201
		returnDict['in3'] = value * 57.75
		returnDict['m3'] = value * 0.0009464
		returnDict['yd3'] = value * 0.0012378
		returnDict['fl oz'] = value * 32.0
		returnDict['gal'] = value * 0.25
		returnDict['L'] = value * 0.9463529
		returnDict['qt'] = value
	return returnDict

def lng_volume(value, units):
	returnDict = {}
	if units == 'BOE':
		returnDict['BOE'] = value
		returnDict['MMBOE'] = value * 1e-06
		returnDict['MMCF'] = value * 0.0056146
		returnDict['KBOE'] = value * 0.001
		returnDict['ton LNG'] = value * 0.1152074
	elif units == 'MMBOE':
		returnDict['BOE'] = value * 1000000.0
		returnDict['MMBOE'] = value
		returnDict['MMCF'] = value * 5614.5833334
		returnDict['KBOE'] = value * 1000.0
		returnDict['ton LNG'] = value * 115207.3732719
	elif units == 'MMCF':
		returnDict['BOE'] = value * 178.1076067
		returnDict['MMBOE'] = value * 0.0001781
		returnDict['MMCF'] = value
		returnDict['KBOE'] = value * 0.1781076
		returnDict['ton LNG'] = value * 20.5193095
	elif units == 'KBOE':
		returnDict['BOE'] = value * 1000.0
		returnDict['MMBOE'] = value * 0.001
		returnDict['MMCF'] = value * 5.6145833
		returnDict['KBOE'] = value
		returnDict['ton LNG'] = value * 115.2073733
	elif units == 'ton LNG':
		returnDict['BOE'] = value * 8.68
		returnDict['MMBOE'] = value * 8.7e-06
		returnDict['MMCF'] = value * 0.0487346
		returnDict['KBOE'] = value * 0.00868
		returnDict['ton LNG'] = value
	return returnDict

def specific_volume(value, units):
	returnDict = {}
	if units == 'bbl/UK ton':
		returnDict['bbl/UK ton'] = value
		returnDict['bbl/US ton'] = value * 0.8928571
		returnDict['ft3/lb'] = value * 0.0025065
		returnDict['in3/lb'] = value * 4.33125
		returnDict['m3/kg'] = value * 0.0001565
		returnDict['UK gal/lb'] = value * 0.0156126
		returnDict['US gal/lb'] = value * 0.01875
		returnDict['l/g'] = value * 0.0001565
		returnDict['l/kg'] = value * 0.1564763
	elif units == 'bbl/US ton':
		returnDict['bbl/UK ton'] = value * 1.12
		returnDict['bbl/US ton'] = value
		returnDict['ft3/lb'] = value * 0.0028073
		returnDict['in3/lb'] = value * 4.851
		returnDict['m3/kg'] = value * 0.0001753
		returnDict['UK gal/lb'] = value * 0.0174862
		returnDict['US gal/lb'] = value * 0.021
		returnDict['l/g'] = value * 0.0001753
		returnDict['l/kg'] = value * 0.1752535
	elif units == 'ft3/lb':
		returnDict['bbl/UK ton'] = value * 398.961039
		returnDict['bbl/US ton'] = value * 356.2152134
		returnDict['ft3/lb'] = value
		returnDict['in3/lb'] = value * 1728.0
		returnDict['m3/kg'] = value * 0.062428
		returnDict['UK gal/lb'] = value * 6.2288384
		returnDict['US gal/lb'] = value * 7.4805195
		returnDict['l/g'] = value * 0.062428
		returnDict['l/kg'] = value * 62.4279606
	elif units == 'in3/lb':
		returnDict['bbl/UK ton'] = value * 0.2308802
		returnDict['bbl/US ton'] = value * 0.2061431
		returnDict['ft3/lb'] = value * 0.0005787
		returnDict['in3/lb'] = value
		returnDict['m3/kg'] = value * 3.61e-05
		returnDict['UK gal/lb'] = value * 0.0036047
		returnDict['US gal/lb'] = value * 0.004329
		returnDict['l/g'] = value * 3.61e-05
		returnDict['l/kg'] = value * 0.0361273
	elif units == 'm3/kg':
		returnDict['bbl/UK ton'] = value * 6390.7427902
		returnDict['bbl/US ton'] = value * 5706.0203484
		returnDict['ft3/lb'] = value * 16.0184634
		returnDict['in3/lb'] = value * 27679.9047102
		returnDict['m3/kg'] = value
		returnDict['UK gal/lb'] = value * 99.7764204
		returnDict['US gal/lb'] = value * 119.8264273
		returnDict['l/g'] = value
		returnDict['l/kg'] = value * 1000.0
	elif units == 'UK gal/lb':
		returnDict['bbl/UK ton'] = value * 64.050632
		returnDict['bbl/US ton'] = value * 57.1880643
		returnDict['ft3/lb'] = value * 0.1605436
		returnDict['in3/lb'] = value * 277.4193
		returnDict['m3/kg'] = value * 0.0100224
		returnDict['UK gal/lb'] = value
		returnDict['US gal/lb'] = value * 1.2009494
		returnDict['l/g'] = value * 0.0100224
		returnDict['l/kg'] = value * 10.0224081
	elif units == 'US gal/lb':
		returnDict['bbl/UK ton'] = value * 53.3333333
		returnDict['bbl/US ton'] = value * 47.6190476
		returnDict['ft3/lb'] = value * 0.1336806
		returnDict['in3/lb'] = value * 231.0
		returnDict['m3/kg'] = value * 0.0083454
		returnDict['UK gal/lb'] = value * 0.8326746
		returnDict['US gal/lb'] = value
		returnDict['l/g'] = value * 0.0083454
		returnDict['l/kg'] = value * 8.3454045
	elif units == 'l/g':
		returnDict['bbl/UK ton'] = value * 6390.7427902
		returnDict['bbl/US ton'] = value * 5706.0203484
		returnDict['ft3/lb'] = value * 16.0184634
		returnDict['in3/lb'] = value * 27679.90471
		returnDict['m3/kg'] = value
		returnDict['UK gal/lb'] = value * 99.7764204
		returnDict['US gal/lb'] = value * 119.8264273
		returnDict['l/g'] = value
		returnDict['l/kg'] = value * 1000.0
	elif units == 'l/kg':
		returnDict['bbl/UK ton'] = value * 6.3907428
		returnDict['bbl/US ton'] = value * 5.7060203
		returnDict['ft3/lb'] = value * 0.0160185
		returnDict['in3/lb'] = value * 27.6799047
		returnDict['m3/kg'] = value * 0.001
		returnDict['UK gal/lb'] = value * 0.0997764
		returnDict['US gal/lb'] = value * 0.1198264
		returnDict['l/g'] = value * 0.001
		returnDict['l/kg'] = value
	return returnDict

def gas_volume(value, units):
	returnDict = {}
	if units == 'bbl':
		returnDict['bbl'] = value
		returnDict['cm3'] = value * 158987.2949285
		returnDict['dm3'] = value * 1589.8729493
		returnDict['ft3'] = value * 5.6145833
		returnDict['in3'] = value * 9702.0
		returnDict['m3'] = value * 0.1589873
		returnDict['yd3'] = value * 0.2079475
		returnDict['fl oz'] = value * 5376.0
		returnDict['gal'] = value * 42.0
		returnDict['L'] = value * 158.9872949
		returnDict['qt'] = value * 168.0
	elif units == 'cm3':
		returnDict['bbl'] = value * 6.3e-06
		returnDict['cm3'] = value
		returnDict['dm3'] = value * 0.01
		returnDict['ft3'] = value * 3.53e-05
		returnDict['in3'] = value * 0.0610237
		returnDict['m3'] = value * 1e-06
		returnDict['yd3'] = value * 1.3e-06
		returnDict['fl oz'] = value * 0.033814
		returnDict['gal'] = value * 0.0002642
		returnDict['L'] = value * 0.001
		returnDict['qt'] = value * 0.0010567
	elif units == 'dm3':
		returnDict['bbl'] = value * 0.000629
		returnDict['cm3'] = value * 100.0
		returnDict['dm3'] = value
		returnDict['ft3'] = value * 0.0035315
		returnDict['in3'] = value * 6.1023744
		returnDict['m3'] = value * 0.0001
		returnDict['yd3'] = value * 0.0001308
		returnDict['fl oz'] = value * 3.3814023
		returnDict['gal'] = value * 0.0264172
		returnDict['L'] = value * 0.1
		returnDict['qt'] = value * 0.1056688
	elif units == 'ft3':
		returnDict['bbl'] = value * 0.1781076
		returnDict['cm3'] = value * 28316.846592
		returnDict['dm3'] = value * 283.1684659
		returnDict['ft3'] = value
		returnDict['in3'] = value * 1728.0
		returnDict['m3'] = value * 0.0283168
		returnDict['yd3'] = value * 0.037037
		returnDict['fl oz'] = value * 957.5064935
		returnDict['gal'] = value * 7.4805195
		returnDict['L'] = value * 28.3168466
		returnDict['qt'] = value * 29.9220779
	elif units == 'in3':
		returnDict['bbl'] = value * 0.0001031
		returnDict['cm3'] = value * 16.387064
		returnDict['dm3'] = value * 0.1638706
		returnDict['ft3'] = value * 0.0005787
		returnDict['in3'] = value
		returnDict['m3'] = value * 1.64e-05
		returnDict['yd3'] = value * 2.14e-05
		returnDict['fl oz'] = value * 0.5541126
		returnDict['gal'] = value * 0.004329
		returnDict['L'] = value * 0.0163871
		returnDict['qt'] = value * 0.017316
	elif units == 'm3':
		returnDict['bbl'] = value * 6.2898108
		returnDict['cm3'] = value * 1000000.0
		returnDict['dm3'] = value * 10000.0
		returnDict['ft3'] = value * 35.3146667
		returnDict['in3'] = value * 61023.7440947
		returnDict['m3'] = value
		returnDict['yd3'] = value * 1.3079506
		returnDict['fl oz'] = value * 33814.0227017
		returnDict['gal'] = value * 264.1720524
		returnDict['L'] = value * 1000.0
		returnDict['qt'] = value * 1056.6882094
	elif units == 'yd3':
		returnDict['bbl'] = value * 4.8089054
		returnDict['cm3'] = value * 764554.857984
		returnDict['dm3'] = value * 7645.5485798
		returnDict['ft3'] = value * 27.0
		returnDict['in3'] = value * 46656.0
		returnDict['m3'] = value * 0.7645549
		returnDict['yd3'] = value
		returnDict['fl oz'] = value * 25852.6753246
		returnDict['gal'] = value * 201.974026
		returnDict['L'] = value * 764.554858
		returnDict['qt'] = value * 807.8961039
	elif units == 'fl oz':
		returnDict['bbl'] = value * 0.000186
		returnDict['cm3'] = value * 29.5735296
		returnDict['dm3'] = value * 0.2957353
		returnDict['ft3'] = value * 0.0010444
		returnDict['in3'] = value * 1.8046875
		returnDict['m3'] = value * 2.96e-05
		returnDict['yd3'] = value * 3.87e-05
		returnDict['fl oz'] = value
		returnDict['gal'] = value * 0.0078125
		returnDict['L'] = value * 0.0295735
		returnDict['qt'] = value * 0.03125
	elif units == ' gal':
		returnDict['bbl'] = value * 0.0238095
		returnDict['cm3'] = value * 3785.411784
		returnDict['dm3'] = value * 37.8541178
		returnDict['ft3'] = value * 0.1336806
		returnDict['in3'] = value * 231.0
		returnDict['m3'] = value * 0.0037854
		returnDict['yd3'] = value * 0.0049511
		returnDict['fl oz'] = value * 128.0
		returnDict['gal'] = value
		returnDict['L'] = value * 3.7854118
		returnDict['qt'] = value * 4.0
	elif units == 'L':
		returnDict['bbl'] = value * 0.0062898
		returnDict['cm3'] = value * 1000.0
		returnDict['dm3'] = value * 10.0
		returnDict['ft3'] = value * 0.0353147
		returnDict['in3'] = value * 61.0237441
		returnDict['m3'] = value * 0.001
		returnDict['yd3'] = value * 0.001308
		returnDict['fl oz'] = value * 33.8140227
		returnDict['gal'] = value * 0.2641721
		returnDict['L'] = value
		returnDict['qt'] = value * 1.0566882
	elif units == 'qt':
		returnDict['bbl'] = value * 0.0059524
		returnDict['cm3'] = value * 946.352946
		returnDict['dm3'] = value * 9.4635295
		returnDict['ft3'] = value * 0.0334201
		returnDict['in3'] = value * 57.75
		returnDict['m3'] = value * 0.0009464
		returnDict['yd3'] = value * 0.0012378
		returnDict['fl oz'] = value * 32.0
		returnDict['gal'] = value * 0.25
		returnDict['L'] = value * 0.9463529
		returnDict['qt'] = value
	return returnDict


def nozzle_size(value, units):
	returnDict = {}
	if units == 'mm':
		returnDict['mm'] = value
		returnDict['1/8in'] = value * 0.3149606
		returnDict['16/in'] = value * 0.6299213
		returnDict['32/in'] = value * 1.2598425
		returnDict['64/in'] = value * 2.519685
	elif units == '1/8in':
		returnDict['mm'] = value * 3.175
		returnDict['1/8in'] = value
		returnDict['16/in'] = value * 2.0
		returnDict['32/in'] = value * 4.0
		returnDict['64/in'] = value * 8.0
	elif units == '16/in':
		returnDict['mm'] = value * 1.5875
		returnDict['1/8in'] = value * 0.5
		returnDict['16/in'] = value
		returnDict['32/in'] = value * 2.0
		returnDict['64/in'] = value * 4.0
	elif units == '32/in':
		returnDict['mm'] = value * 0.79375
		returnDict['1/8in'] = value * 0.25
		returnDict['16/in'] = value * 0.5
		returnDict['32/in'] = value
		returnDict['64/in'] = value * 2.0
	elif units == '64/in':
		returnDict['mm'] = value * 0.396875
		returnDict['1/8in'] = value * 0.125
		returnDict['16/in'] = value * 0.25
		returnDict['32/in'] = value * 0.5
		returnDict['64/in'] = value
	return returnDict

def nozzle_speed(value, units):
	returnDict = {}
	if units == 'ft/s':
		returnDict['ft/s'] = value
		returnDict['m/s'] = value * 0.3048
	elif units == 'm/s':
		returnDict['ft/s'] = value * 3.2808399
		returnDict['m/s'] = value
	return returnDict

def oil_production_index(value, units):
	returnDict = {}
	if units == 'bbl/d-psi':
		returnDict['bbl/d-psi'] = value
		returnDict['bbl/hr-psi'] = value * 0.041667
		returnDict['bbl/min-psi'] = value * 0.0006944
		returnDict['ft3/d-psi'] = value * 5.6146008
		returnDict['m3/d-kPa'] = value * 0.0230592
		returnDict['m3/d-MPa'] = value * 23.05916
		returnDict['m3/hr-kPa'] = value * 0.0009601
		returnDict['gal/d-psi'] = value * 41.9999709
		returnDict['l/hr-kPa'] = value * 0.9600727
	elif units == 'bbl/hr-psi':
		returnDict['bbl/d-psi'] = value * 23.9998118
		returnDict['bbl/hr-psi'] = value
		returnDict['bbl/min-psi'] = value * 0.0166664
		returnDict['ft3/d-psi'] = value * 134.7493632
		returnDict['m3/d-kPa'] = value * 0.5534155
		returnDict['m3/d-MPa'] = value * 553.4155
		returnDict['m3/hr-kPa'] = value * 0.0230416
		returnDict['gal/d-psi'] = value * 1007.9913957
		returnDict['l/hr-kPa'] = value * 23.0415636
	elif units == 'bbl/min-psi':
		returnDict['bbl/d-psi'] = value * 1440.0095233
		returnDict['bbl/hr-psi'] = value * 60.0008673
		returnDict['bbl/min-psi'] = value
		returnDict['ft3/d-psi'] = value * 8085.0786669
		returnDict['m3/d-kPa'] = value * 33.20541
		returnDict['m3/d-MPa'] = value * 33205.41
		returnDict['m3/hr-kPa'] = value * 1.3825138
		returnDict['gal/d-psi'] = value * 60480.3580145
		returnDict['l/hr-kPa'] = value * 1382.5138
	elif units == 'ft3/d-psi':
		returnDict['bbl/d-psi'] = value * 0.1781071
		returnDict['bbl/hr-psi'] = value * 0.0074212
		returnDict['bbl/min-psi'] = value * 0.0001237
		returnDict['ft3/d-psi'] = value
		returnDict['m3/d-kPa'] = value * 0.004107
		returnDict['m3/d-MPa'] = value * 4.106999
		returnDict['m3/hr-kPa'] = value * 0.000171
		returnDict['gal/d-psi'] = value * 7.480491
		returnDict['l/hr-kPa'] = value * 0.1709957
	elif units == 'm3/d-kPa':
		returnDict['bbl/d-psi'] = value * 43.3667141
		returnDict['bbl/hr-psi'] = value * 1.8069606
		returnDict['bbl/min-psi'] = value * 0.0301156
		returnDict['ft3/d-psi'] = value * 243.4867893
		returnDict['m3/d-kPa'] = value
		returnDict['m3/d-MPa'] = value * 1000.0
		returnDict['m3/hr-kPa'] = value * 0.0416352
		returnDict['gal/d-psi'] = value * 1821.40073
		returnDict['l/hr-kPa'] = value * 41.6351974
	elif units == 'm3/d-MPa':
		returnDict['bbl/d-psi'] = value * 0.0433667
		returnDict['bbl/hr-psi'] = value * 0.001807
		returnDict['bbl/min-psi'] = value * 3.01e-05
		returnDict['ft3/d-psi'] = value * 0.2434868
		returnDict['m3/d-kPa'] = value * 0.001
		returnDict['m3/d-MPa'] = value
		returnDict['m3/hr-kPa'] = value * 4.16e-05
		returnDict['gal/d-psi'] = value * 1.8214007
		returnDict['l/hr-kPa'] = value * 0.0416352
	elif units == 'm3/hr-kPa':
		returnDict['bbl/d-psi'] = value * 1041.5878115
		returnDict['bbl/hr-psi'] = value * 43.3998325
		returnDict['bbl/min-psi'] = value * 0.7233201
		returnDict['ft3/d-psi'] = value * 5848.0997926
		returnDict['m3/d-kPa'] = value * 24.01814
		returnDict['m3/d-MPa'] = value * 24018.14
		returnDict['m3/hr-kPa'] = value
		returnDict['gal/d-psi'] = value * 43746.6577297
		returnDict['l/hr-kPa'] = value * 1000.0
	elif units == 'gal/d-psi':
		returnDict['bbl/d-psi'] = value * 0.0238095
		returnDict['bbl/hr-psi'] = value * 0.0009921
		returnDict['bbl/min-psi'] = value * 1.65e-05
		returnDict['ft3/d-psi'] = value * 0.1336811
		returnDict['m3/d-kPa'] = value * 0.000549
		returnDict['m3/d-MPa'] = value * 0.549028
		returnDict['m3/hr-kPa'] = value * 2.29e-05
		returnDict['gal/d-psi'] = value
		returnDict['l/hr-kPa'] = value * 0.0228589
	elif units == 'l/hr-kPa':
		returnDict['bbl/d-psi'] = value * 1.0415878
		returnDict['bbl/hr-psi'] = value * 0.0433998
		returnDict['bbl/min-psi'] = value * 0.0007233
		returnDict['ft3/d-psi'] = value * 5.8480998
		returnDict['m3/d-kPa'] = value * 0.0240181
		returnDict['m3/d-MPa'] = value * 24.01814
		returnDict['m3/hr-kPa'] = value * 0.001
		returnDict['gal/d-psi'] = value * 43.7466577
		returnDict['l/hr-kPa'] = value
	return returnDict

def permeability(value, units):
	returnDict = {}
	if units == 'darcy':
		returnDict['darcy'] = value
		returnDict['md'] = value * 1000
		returnDict['ud'] = value * 1000000
		returnDict['m2'] = value * 0.0000000000009869
		returnDict['ft2'] = value * 1.06235016146393e-11
	elif units == 'md':
		returnDict['darcy'] = value * 0.001
		returnDict['md'] = value
		returnDict['ud'] = value * 1000
		returnDict['m2'] = value * 0.0000000000000009869
		returnDict['ft2'] = value * 1.06235016146393e-14
	elif units == 'ud':
		returnDict['darcy'] = value * 0.000001
		returnDict['md'] = value * 0.001
		returnDict['ud'] = value
		returnDict['m2'] = value * 9.869e-19
		returnDict['ft2'] = value * 1.06235016146393e-17
	elif units == 'm2':
		returnDict['darcy'] = value * 1013273887931.91
		returnDict['md'] = value * 1013273887931910
		returnDict['ud'] = value * 1013273887931910000
		returnDict['m2'] = value 
		returnDict['ft2'] = value * 0.0000107642626480086
	elif units == 'ft2':
		returnDict['darcy'] = value * 94130921825.4355
		returnDict['md'] = value * 94130921825435.5
		returnDict['ud'] = value * 94130921825435500
		returnDict['m2'] = value * 92900.0000000001
		returnDict['ft2'] = value 
	return returnDict

def pipe_capacity(value, units):
	returnDict = {}
	if units == 'bbl/ft':
		returnDict['bbl/ft'] = value
		returnDict['m3/m'] = value * 0.521654
		returnDict['bbl/in'] = value * 0.0833333333333333
		returnDict['ft3/ft'] = value * 5.61458333333333
		returnDict['gal(us)/ft'] = value * 42.0
		returnDict['l/m'] = value * 521.61186
		returnDict['dm3/m'] = value * 521.61186
		returnDict['in3/ft'] = value * 9702.0
	elif units == 'm3/m':
		returnDict['bbl/ft'] = value * 1.9169795
		returnDict['m3/m'] = value
		returnDict['bbl/in'] = value * 0.159761193568975
		returnDict['ft3/ft'] = value * 10.7639104167097
		returnDict['gal(us)/ft'] = value * 80.5196415587636
		returnDict['l/m'] = value * 1000.0
		returnDict['dm3/m'] = value * 1000.0
		returnDict['in3/ft'] = value * 18600.0372000744
	elif units == 'bbl/in':
		returnDict['bbl/ft'] = value * 12.000000000000005
		returnDict['m3/m'] = value * 6.259342320000019
		returnDict['bbl/in'] = value
		returnDict['ft3/ft'] = value * 67.375
		returnDict['gal(us)/ft'] = value * 504.0
		returnDict['l/m'] = value * 6259.34232
		returnDict['dm3/m'] = value * 6259.34232
		returnDict['in3/ft'] = value * 116424.0
	elif units == 'ft3/ft':
		returnDict['bbl/ft'] = value * 0.17810760667903536
		returnDict['m3/m'] = value * 0.09290304000000019
		returnDict['bbl/in'] = value * 0.014842300556586271
		returnDict['ft3/ft'] = value
		returnDict['gal(us)/ft'] = value * 7.48051948051948
		returnDict['l/m'] = value * 92.90304
		returnDict['dm3/m'] = value * 92.90304
		returnDict['in3/ft'] = value * 1728.0
	elif units == 'gal(us)/ft':
		returnDict['bbl/ft'] = value * 0.023809523809523808
		returnDict['m3/m'] = value * 0.012419330000000006
		returnDict['bbl/in'] = value * 0.001984126984126984
		returnDict['ft3/ft'] = value * 0.13368055555555555
		returnDict['gal(us)/ft'] = value
		returnDict['l/m'] = value * 12.4193299999999
		returnDict['dm3/m'] = value * 12.4193299999999
		returnDict['in3/ft'] = value * 231.0
	elif units == 'l/m':
		returnDict['bbl/ft'] = value * 0.0019171343228277058
		returnDict['m3/m'] = value * 0.001
		returnDict['bbl/in'] = value * 0.00015976119356897548
		returnDict['ft3/ft'] = value * 0.010763910416709722
		returnDict['gal(us)/ft'] = value * 0.08051964155876429
		returnDict['l/m'] = value
		returnDict['dm3/m'] = value
		returnDict['in3/ft'] = value * 18.6000372000744
	elif units == 'dm3/m':
		returnDict['bbl/ft'] = value * 0.0019171343228277058
		returnDict['m3/m'] = value * 0.001
		returnDict['bbl/in'] = value * 0.00015976119356897548
		returnDict['ft3/ft'] = value * 0.010763910416709722
		returnDict['gal(us)/ft'] = value * 0.08051964155876429
		returnDict['l/m'] = value
		returnDict['dm3/m'] = value
		returnDict['in3/ft'] = value * 18.6000372000744
	elif units == 'in3/ft':
		returnDict['bbl/ft'] = value * 0.00010307153164296021
		returnDict['m3/m'] = value * 5.3763333333333334e-05
		returnDict['bbl/in'] = value * 8.589294303580018e-06
		returnDict['ft3/ft'] = value * 0.0005787037037037037
		returnDict['gal(us)/ft'] = value * 0.004329004329004329
		returnDict['l/m'] = value * 0.05376333333333334
		returnDict['dm3/m'] = value * 0.05376333333333334
		returnDict['in3/ft'] = value
	return returnDict

def pipe_cap_length_vol(value, units):
	returnDict = {}
	if units == 'm/m3':
		returnDict['m/m3'] = value
		returnDict['ft/bbl'] = value * 0.52161186
		returnDict['ft/ft3'] = value * 0.09290304
		returnDict['ft/gal(us)'] = value * 0.01241933
	elif units == 'ft/bbl':
		returnDict['m/m3'] = value * 1.9171343228277056
		returnDict['ft/bbl'] = value
		returnDict['ft/ft3'] = value * 0.178107606679035
		returnDict['ft/gal(us)'] = value * 0.0238095238095238
	elif units == 'ft/ft3':
		returnDict['m/m3'] = value * 1.9171343228277056
		returnDict['ft/bbl'] = value * 5.614583333333341
		returnDict['ft/ft3'] = value
		returnDict['ft/gal(us)'] = value * 0.133680555555555
	elif units == 'ft/gal(us)':
		returnDict['m/m3'] = value * 80.51964155876364
		returnDict['ft/bbl'] = value * 42.000000000000014
		returnDict['ft/ft3'] = value * 7.480519480519511
		returnDict['ft/gal(us)'] = value
	return returnDict

def production_rate(value, units):
	returnDict = {}
	if units == 'm3/d':
		returnDict['m3/d'] = value
		returnDict['STB/d'] = value * 6.2893082
	elif units == 'STB/d':
		returnDict['m3/d'] = value * 0.159
		returnDict['STB/d'] = value
	return returnDict

def rotation(value, units):
	returnDict = {}
	if units == 'rad/sec':
		returnDict['rad/sec'] = value
		returnDict['rpm'] = value * 9.551099
	elif units == 'rpm':
		returnDict['rad/sec'] = value * 0.1047
		returnDict['rpm'] = value
	return returnDict

def section_modulus(value, units):
	returnDict = {}
	if units == 'cm3':
		returnDict['cm3'] = value
		returnDict['in3'] = value * 0.061024
	elif units == 'in3':
		returnDict['cm3'] = value * 16.3869953
		returnDict['in3'] = value
	return returnDict

def moment_of_section(value, units):
	returnDict = {}
	if units == 'cm4':
		returnDict['cm4'] = value
		returnDict['ft4'] = value * 1.2e-06
		returnDict['in4'] = value * 0.0240251
		returnDict['m4'] = value * 1e-08
	elif units == 'ft4':
		returnDict['cm4'] = value * 863097.4841242
		returnDict['ft4'] = value
		returnDict['in4'] = value * 20736.0
		returnDict['m4'] = value * 0.008631
	elif units == 'in4':
		returnDict['cm4'] = value * 41.6231426
		returnDict['ft4'] = value * 4.82e-05
		returnDict['in4'] = value
		returnDict['m4'] = value * 4.162314256e-07
	elif units == 'm4':
		returnDict['cm4'] = value * 100000000.0
		returnDict['ft4'] = value * 115.8617675
		returnDict['in4'] = value * 2402509.6100288
		returnDict['m4'] = value
	return returnDict

def stress_elastic_modulus(value, units):
	returnDict = {}
	if units == 'kg/cm2':
		returnDict['kg/cm2'] = value
		returnDict['kPa'] = value * 98.0654748
		returnDict['Mpa'] = value * 0.0980657
		returnDict['Pa'] = value * 98087.7931034
		returnDict['psi'] = value * 14.22273
	elif units == 'kPa':
		returnDict['kg/cm2'] = value * 0.0101973
		returnDict['kPa'] = value
		returnDict['Mpa'] = value * 0.001
		returnDict['Pa'] = value * 1000.2275862
		returnDict['psi'] = value * 0.145033
	elif units == 'Mpa':
		returnDict['kg/cm2'] = value * 10.1972406
		returnDict['kPa'] = value * 1000.0
		returnDict['Mpa'] = value
		returnDict['Pa'] = value * 1000224.8275862
		returnDict['psi'] = value * 145.0326
	elif units == 'Pa':
		returnDict['kg/cm2'] = value * 1.02e-05
		returnDict['kPa'] = value * 0.001
		returnDict['Mpa'] = value * 1e-06
		returnDict['Pa'] = value
		returnDict['psi'] = value * 0.000145
	elif units == 'psi':
		returnDict['kg/cm2'] = value * 0.07031
		returnDict['kPa'] = value * 6.8949825
		returnDict['Mpa'] = value * 0.006895
		returnDict['Pa'] = value * 6896.5517241
		returnDict['psi'] = value * 1.0
	return returnDict

def stroke_rate(value, units):
	returnDict = {}
	if units == 'stk/hr':
		returnDict['stk/hr'] = value
		returnDict['stk/min'] = value * 60.0
	elif units == 'stk/min':
		returnDict['stk/hr'] = value * 0.016667
		returnDict['stk/min'] = value * 1.0
	return returnDict

def stroke_volume(value, units):
	returnDict = {}
	if units == 'bbl/stk':
		returnDict['bbl/stk'] = value
		returnDict['m3/stk'] = value * 0.1590336
		returnDict['gal/stk'] = value * 42.01681
		returnDict['L/stk'] = value * 159.033501
	elif units == 'm3/stk':
		returnDict['bbl/stk'] = value * 6.2879785
		returnDict['m3/stk'] = value
		returnDict['gal/stk'] = value * 264.2008
		returnDict['L/stk'] = value * 1000.0
	elif units == 'gal/stk':
		returnDict['bbl/stk'] = value * 0.0238
		returnDict['m3/stk'] = value * 0.003785
		returnDict['gal/stk'] = value
		returnDict['L/stk'] = value * 3.784997
	elif units == 'L/stk':
		returnDict['bbl/stk'] = value * 0.006288
		returnDict['m3/stk'] = value * 0.001
		returnDict['gal/stk'] = value * 0.264201
		returnDict['L/stk'] = value
	return returnDict

# def permeability(value, units):
# 	returnDict = {}
# 	if units == 'TD':
# 		returnDict['TD'] = value
# 		returnDict['D'] = value * 0.1590336
# 		returnDict['mD'] = value * 42.01681
# 	elif units == 'D':
# 		returnDict['TD'] = value * 1e-12
# 		returnDict['D'] = value
# 		returnDict['mD'] = value * 264.2008
# 	elif units == 'mD':
# 		returnDict['TD'] = value * 0.0238
# 		returnDict['D'] = value * 0.003785
# 		returnDict['mD'] = value
# 	return returnDict



def fluid_consistency(value, units):
    returnDict = {}
    if units == 'dyne-s^n/cm2':
        returnDict['dyne-s^n/cm2'] = value
		returnDict['eq.cp'] = value * 99.4285714
		returnDict['lbf-s^n/100ft2'] = value * 0.2088
		returnDict['lbf-s^n/ft2'] = value * 0.002088
		returnDict['Pa-s^n'] = value * 0.0999761
	elif units == 'eq.cp':
		returnDict['dyne-s^n/cm2'] = value * 0.0100575
		returnDict['eq.cp'] = value
		returnDict['lbf-s^n/100ft2'] = value * 0.0021
		returnDict['lbf-s^n/ft2'] = value * 2.1e-05
		returnDict['Pa-s^n'] = value * 0.0010055
	elif units == 'lbf-s^n/100ft2':
		returnDict['dyne-s^n/cm2'] = value * 4.789272
		returnDict['eq.cp'] = value * 476.1904762
		returnDict['lbf-s^n/100ft2'] = value
		returnDict['lbf-s^n/ft2'] = value * 0.01
		returnDict['Pa-s^n'] = value * 0.4788125
	elif units == 'lbf-s^n/ft2':
		returnDict['dyne-s^n/cm2'] = value * 478.9272031
		returnDict['eq.cp'] = value * 47619.047619
		returnDict['lbf-s^n/100ft2'] = value * 100.0
		returnDict['lbf-s^n/ft2'] = value
		returnDict['Pa-s^n'] = value * 47.8812545
	elif units == 'Pa-s^n':
		returnDict['dyne-s^n/cm2'] = value * 10.0023946
		returnDict['eq.cp'] = value * 994.5238095
		returnDict['lbf-s^n/100ft2'] = value * 2.0885
		returnDict['lbf-s^n/ft2'] = value * 0.020885
		returnDict['Pa-s^n'] = value
	return returnDict


def fluid_yield_point(value, units):
	returnDict = {}
	if units == 'dyne/cm2':
		returnDict['dyne/cm2'] = value
		returnDict['kPa'] = value * 0.0999587
		returnDict['Mpa'] = value * 0.0001
		returnDict['lbf/100ft2'] = value * 0.208768
	elif units == 'kPa':
		returnDict['dyne/cm2'] = value * 10.0041338
		returnDict['kPa'] = value
		returnDict['Mpa'] = value * 0.001
		returnDict['lbf/100ft2'] = value * 2.088543
	elif units == 'Mpa':
		returnDict['dyne/cm2'] = value * 10004.1337753
		returnDict['kPa'] = value * 1000.0
		returnDict['Mpa'] = value
		returnDict['lbf/100ft2'] = value * 2088.543
	elif units == 'lbf/100ft2':
		returnDict['dyne/cm2'] = value * 4.7900061
		returnDict['kPa'] = value * 0.4788027
		returnDict['Mpa'] = value * 0.0004788
		returnDict['lbf/100ft2'] = value
	return returnDict


def liquid_production_rates(value, units):
	returnDict = {}
	if units == 'BPD':
		returnDict['BPD'] = value
		returnDict['BPH'] = value * 0.0416667
		returnDict['BPM'] = value * 0.0006944
		returnDict['BPS'] = value * 1.16e-05
		returnDict['ft3/day'] = value * 5.6145928
		returnDict['ft3/hr'] = value * 0.2339414
		returnDict['ft3/min'] = value * 0.003899
		returnDict['ft3/sec'] = value * 6.5e-05
		returnDict['m3/day'] = value * 0.1589873
		returnDict['m3/hr'] = value * 0.0066245
		returnDict['m3/min'] = value * 0.0001104
		returnDict['gal/day'] = value * 42.0000211
		returnDict['gph'] = value * 1.7500009
		returnDict['gpm'] = value * 0.0291667
		returnDict['gal/sec'] = value * 0.0004861
		returnDict['UK gal/day'] = value * 34.9723169
		returnDict['UK gph'] = value * 1.4571799
		returnDict['UK gpm'] = value * 0.0242863
		returnDict['UK gal/sec'] = value * 0.0004048
	elif units == 'BPH':
		returnDict['BPD'] = value * 24.0
		returnDict['BPH'] = value
		returnDict['BPM'] = value * 0.0166667
		returnDict['BPS'] = value * 0.0002778
		returnDict['ft3/day'] = value * 134.750226
		returnDict['ft3/hr'] = value * 5.6145928
		returnDict['ft3/min'] = value * 0.0935765
		returnDict['ft3/sec'] = value * 0.0015596
		returnDict['m3/day'] = value * 3.8156952
		returnDict['m3/hr'] = value * 0.1589873
		returnDict['m3/min'] = value * 0.0026498
		returnDict['gal/day'] = value * 1008.0005072
		returnDict['gph'] = value * 42.0000211
		returnDict['gpm'] = value * 0.7000004
		returnDict['gal/sec'] = value * 0.0116667
		returnDict['UK gal/day'] = value * 839.3356049
		returnDict['UK gph'] = value * 34.9723169
		returnDict['UK gpm'] = value * 0.5828719
		returnDict['UK gal/sec'] = value * 0.0097145
	elif units == 'BPM':
		returnDict['BPD'] = value * 1440.0
		returnDict['BPH'] = value * 60.0
		returnDict['BPM'] = value
		returnDict['BPS'] = value * 0.0166667
		returnDict['ft3/day'] = value * 8085.0135609
		returnDict['ft3/hr'] = value * 336.875565
		returnDict['ft3/min'] = value * 5.6145928
		returnDict['ft3/sec'] = value * 0.0935765
		returnDict['m3/day'] = value * 228.941712
		returnDict['m3/hr'] = value * 9.539238
		returnDict['m3/min'] = value * 0.1589873
		returnDict['gal/day'] = value * 60480.0304326
		returnDict['gph'] = value * 2520.001268
		returnDict['gpm'] = value * 42.0000211
		returnDict['gal/sec'] = value * 0.7000004
		returnDict['UK gal/day'] = value * 50360.1362929
		returnDict['UK gph'] = value * 2098.3390122
		returnDict['UK gpm'] = value * 34.9723169
		returnDict['UK gal/sec'] = value * 0.5828719
	elif units == 'BPS':
		returnDict['BPD'] = value * 86400.0
		returnDict['BPH'] = value * 3600.0
		returnDict['BPM'] = value * 60.0
		returnDict['BPS'] = value
		returnDict['ft3/day'] = value * 485100.8136513
		returnDict['ft3/hr'] = value * 20212.5339021
		returnDict['ft3/min'] = value * 336.875565
		returnDict['ft3/sec'] = value * 5.6145928
		returnDict['m3/day'] = value * 13736.50272
		returnDict['m3/hr'] = value * 572.35428
		returnDict['m3/min'] = value * 9.539238
		returnDict['gal/day'] = value * 3628801.8259581
		returnDict['gph'] = value * 151200.0760816
		returnDict['gpm'] = value * 2520.001268
		returnDict['gal/sec'] = value * 42.0000211
		returnDict['UK gal/day'] = value * 3021608.1775768
		returnDict['UK gph'] = value * 125900.3407324
		returnDict['UK gpm'] = value * 2098.3390122
		returnDict['UK gal/sec'] = value * 34.9723169
	elif units == 'ft3/day':
		returnDict['BPD'] = value * 0.1781073
		returnDict['BPH'] = value * 0.0074211
		returnDict['BPM'] = value * 0.0001237
		returnDict['BPS'] = value * 2.1e-06
		returnDict['ft3/day'] = value
		returnDict['ft3/hr'] = value * 0.0416667
		returnDict['ft3/min'] = value * 0.0006944
		returnDict['ft3/sec'] = value * 1.16e-05
		returnDict['m3/day'] = value * 0.0283168
		returnDict['m3/hr'] = value * 0.0011799
		returnDict['m3/min'] = value * 1.97e-05
		returnDict['gal/day'] = value * 7.4805107
		returnDict['gph'] = value * 0.3116879
		returnDict['gpm'] = value * 0.0051948
		returnDict['gal/sec'] = value * 8.66e-05
		returnDict['UK gal/day'] = value * 6.2288252
		returnDict['UK gph'] = value * 0.2595344
		returnDict['UK gpm'] = value * 0.0043256
		returnDict['UK gal/sec'] = value * 7.21e-05
	elif units == 'ft3/hr':
		returnDict['BPD'] = value * 4.2745754
		returnDict['BPH'] = value * 0.1781073
		returnDict['BPM'] = value * 0.0029685
		returnDict['BPS'] = value * 4.95e-05
		returnDict['ft3/day'] = value * 24.0
		returnDict['ft3/hr'] = value
		returnDict['ft3/min'] = value * 0.0166667
		returnDict['ft3/sec'] = value * 0.0002778
		returnDict['m3/day'] = value * 0.6796032
		returnDict['m3/hr'] = value * 0.0283168
		returnDict['m3/min'] = value * 0.0283168
		returnDict['gal/day'] = value * 179.5322567
		returnDict['gph'] = value * 7.4805107
		returnDict['gpm'] = value * 0.1246752
		returnDict['gal/sec'] = value * 0.0020779
		returnDict['UK gal/day'] = value * 149.491805
		returnDict['UK gph'] = value * 6.2288252
		returnDict['UK gpm'] = value * 0.1038138
		returnDict['UK gal/sec'] = value * 0.0017302
	elif units == 'ft3/min':
		returnDict['BPD'] = value * 256.4745234
		returnDict['BPH'] = value * 10.6864385
		returnDict['BPM'] = value * 0.1781073
		returnDict['BPS'] = value * 0.0029685
		returnDict['ft3/day'] = value * 1440.0
		returnDict['ft3/hr'] = value * 60.0
		returnDict['ft3/min'] = value
		returnDict['ft3/sec'] = value * 0.0166667
		returnDict['m3/day'] = value * 40.776192
		returnDict['m3/hr'] = value * 1.699008
		returnDict['m3/min'] = value * 0.0283168
		returnDict['gal/day'] = value * 10771.9354046
		returnDict['gph'] = value * 448.8306419
		returnDict['gpm'] = value * 7.4805107
		returnDict['gal/sec'] = value * 0.1246752
		returnDict['UK gal/day'] = value * 8969.5083027
		returnDict['UK gph'] = value * 373.7295126
		returnDict['UK gpm'] = value * 6.2288252
		returnDict['UK gal/sec'] = value * 0.1038138
	elif units == 'ft3/sec':
		returnDict['BPD'] = value * 15388.4714062
		returnDict['BPH'] = value * 641.1863086
		returnDict['BPM'] = value * 10.6864385
		returnDict['BPS'] = value * 0.1781073
		returnDict['ft3/day'] = value * 86400.0
		returnDict['ft3/hr'] = value * 3600.0
		returnDict['ft3/min'] = value * 60.0
		returnDict['ft3/sec'] = value
		returnDict['m3/day'] = value * 2446.57152
		returnDict['m3/hr'] = value * 101.94048
		returnDict['m3/min'] = value * 1.699008
		returnDict['gal/day'] = value * 646316.1242772
		returnDict['gph'] = value * 26929.8385115
		returnDict['gpm'] = value * 448.8306419
		returnDict['gal/sec'] = value * 7.4805107
		returnDict['UK gal/day'] = value * 538170.4981644
		returnDict['UK gph'] = value * 22423.7707568
		returnDict['UK gpm'] = value * 373.7295126
		returnDict['UK gal/sec'] = value * 6.2288252
	elif units == 'm3/day':
		returnDict['BPD'] = value * 6.2898106
		returnDict['BPH'] = value * 0.2620754
		returnDict['BPM'] = value * 0.0043679
		returnDict['BPS'] = value * 7.28e-05
		returnDict['ft3/day'] = value * 35.3147248
		returnDict['ft3/hr'] = value * 1.4714469
		returnDict['ft3/min'] = value * 0.0245241
		returnDict['ft3/sec'] = value * 0.0004087
		returnDict['m3/day'] = value
		returnDict['m3/hr'] = value * 0.0416667
		returnDict['m3/min'] = value * 0.0006944
		returnDict['gal/day'] = value * 264.1721769
		returnDict['gph'] = value * 11.007174
		returnDict['gpm'] = value * 0.1834529
		returnDict['gal/sec'] = value * 0.0030575
		returnDict['UK gal/day'] = value * 219.9692483
		returnDict['UK gph'] = value * 9.1653853
		returnDict['UK gpm'] = value * 0.1527564
		returnDict['UK gal/sec'] = value * 0.0025459
	elif units == 'm3/hr':
		returnDict['BPD'] = value * 150.9554537
		returnDict['BPH'] = value * 6.2898106
		returnDict['BPM'] = value * 0.1048302
		returnDict['BPS'] = value * 0.0017472
		returnDict['ft3/day'] = value * 847.5533959
		returnDict['ft3/hr'] = value * 35.3147248
		returnDict['ft3/min'] = value * 0.5885787
		returnDict['ft3/sec'] = value * 0.0098096
		returnDict['m3/day'] = value * 24.0
		returnDict['m3/hr'] = value
		returnDict['m3/min'] = value * 0.0166667
		returnDict['gal/day'] = value * 6340.1322446
		returnDict['gph'] = value * 264.1721769
		returnDict['gpm'] = value * 4.4028696
		returnDict['gal/sec'] = value * 0.0733812
		returnDict['UK gal/day'] = value * 5279.2619592
		returnDict['UK gph'] = value * 219.9692483
		returnDict['UK gpm'] = value * 3.6661541
		returnDict['UK gal/sec'] = value * 0.0611026
	elif units == 'm3/min':
		returnDict['BPD'] = value * 9057.3272205
		returnDict['BPH'] = value * 377.3886342
		returnDict['BPM'] = value * 6.2898106
		returnDict['BPS'] = value * 0.1048302
		returnDict['ft3/day'] = value * 50853.2037518
		returnDict['ft3/hr'] = value * 2118.8834897
		returnDict['ft3/min'] = value * 35.3147248
		returnDict['ft3/sec'] = value * 0.5885787
		returnDict['m3/day'] = value * 1440.0
		returnDict['m3/hr'] = value * 60.0
		returnDict['m3/min'] = value
		returnDict['gal/day'] = value * 380407.9346755
		returnDict['gph'] = value * 15850.3306115
		returnDict['gpm'] = value * 264.1721769
		returnDict['gal/sec'] = value * 4.4028696
		returnDict['UK gal/day'] = value * 316755.7175507
		returnDict['UK gph'] = value * 13198.1548979
		returnDict['UK gpm'] = value * 219.9692483
		returnDict['UK gal/sec'] = value * 3.6661541
	elif units == 'gal/day':
		returnDict['BPD'] = value * 0.0238095
		returnDict['BPH'] = value * 0.0009921
		returnDict['BPM'] = value * 1.65e-05
		returnDict['BPS'] = value * 2.75e-07
		returnDict['ft3/day'] = value * 0.1336807
		returnDict['ft3/hr'] = value * 0.00557
		returnDict['ft3/min'] = value * 9.28e-05
		returnDict['ft3/sec'] = value * 1.5e-06
		returnDict['m3/day'] = value * 0.0037854
		returnDict['m3/hr'] = value * 0.0001577
		returnDict['m3/min'] = value * 2.6e-06
		returnDict['gal/day'] = value
		returnDict['gph'] = value * 0.0416667
		returnDict['gpm'] = value * 0.0006944
		returnDict['gal/sec'] = value * 1.16e-05
		returnDict['UK gal/day'] = value * 0.8326738
		returnDict['UK gph'] = value * 0.0346947
		returnDict['UK gpm'] = value * 0.0005782
		returnDict['UK gal/sec'] = value * 9.6e-06
	elif units == 'gph':
		returnDict['BPD'] = value * 0.5714283
		returnDict['BPH'] = value * 0.0238095
		returnDict['BPM'] = value * 0.0003968
		returnDict['BPS'] = value * 6.6e-06
		returnDict['ft3/day'] = value * 3.2083371
		returnDict['ft3/hr'] = value * 0.1336807
		returnDict['ft3/min'] = value * 0.002228
		returnDict['ft3/sec'] = value * 3.71e-05
		returnDict['m3/day'] = value * 0.0908498
		returnDict['m3/hr'] = value * 0.0037854
		returnDict['m3/min'] = value * 6.31e-05
		returnDict['gal/day'] = value * 24.0
		returnDict['gph'] = value
		returnDict['gpm'] = value * 0.0166667
		returnDict['gal/sec'] = value * 0.0002778
		returnDict['UK gal/day'] = value * 19.984171
		returnDict['UK gph'] = value * 0.8326738
		returnDict['UK gpm'] = value * 0.0138779
		returnDict['UK gal/sec'] = value * 0.0002313
	elif units == 'gpm':
		returnDict['BPD'] = value * 34.285697
		returnDict['BPH'] = value * 1.4285707
		returnDict['BPM'] = value * 0.0238095
		returnDict['BPS'] = value * 0.0003968
		returnDict['ft3/day'] = value * 192.500226
		returnDict['ft3/hr'] = value * 8.0208428
		returnDict['ft3/min'] = value * 0.1336807
		returnDict['ft3/sec'] = value * 0.002228
		returnDict['m3/day'] = value * 5.4509904
		returnDict['m3/hr'] = value * 0.2271246
		returnDict['m3/min'] = value * 0.0037854
		returnDict['gal/day'] = value * 1440.0
		returnDict['gph'] = value * 60.0
		returnDict['gpm'] = value
		returnDict['gal/sec'] = value * 0.0166667
		returnDict['UK gal/day'] = value * 1199.0502608
		returnDict['UK gph'] = value * 49.9604275
		returnDict['UK gpm'] = value * 0.8326738
		returnDict['UK gal/sec'] = value * 0.0138779
	elif units == 'gal/sec':
		returnDict['BPD'] = value * 2057.141822
		returnDict['BPH'] = value * 85.7142426
		returnDict['BPM'] = value * 1.4285707
		returnDict['BPS'] = value * 0.0238095
		returnDict['ft3/day'] = value * 11550.0135609
		returnDict['ft3/hr'] = value * 481.250565
		returnDict['ft3/min'] = value * 8.0208428
		returnDict['ft3/sec'] = value * 0.1336807
		returnDict['m3/day'] = value * 327.059424
		returnDict['m3/hr'] = value * 13.627476
		returnDict['m3/min'] = value * 0.2271246
		returnDict['gal/day'] = value * 86400.0
		returnDict['gph'] = value * 3600.0
		returnDict['gpm'] = value * 60.0
		returnDict['gal/sec'] = value
		returnDict['UK gal/day'] = value * 71943.0156464
		returnDict['UK gph'] = value * 2997.6256519
		returnDict['UK gpm'] = value * 49.9604275
		returnDict['UK gal/sec'] = value * 0.8326738
	elif units == 'UK gal/day':
		returnDict['BPD'] = value * 0.028594
		returnDict['BPH'] = value * 0.0011914
		returnDict['BPM'] = value * 1.99e-05
		returnDict['BPS'] = value * 3.3167e-07
		returnDict['ft3/day'] = value * 0.1605439
		returnDict['ft3/hr'] = value * 0.0066893
		returnDict['ft3/min'] = value * 0.0001115
		returnDict['ft3/sec'] = value * 1.9e-06
		returnDict['m3/day'] = value * 0.0045461
		returnDict['m3/hr'] = value * 0.0001894
		returnDict['m3/min'] = value * 3.2e-06
		returnDict['gal/day'] = value * 1.2009505
		returnDict['gph'] = value * 0.0500396
		returnDict['gpm'] = value * 0.000834
		returnDict['gal/sec'] = value * 1.39e-05
		returnDict['UK gal/day'] = value
		returnDict['UK gph'] = value * 0.0416667
		returnDict['UK gpm'] = value * 0.0006944
		returnDict['UK gal/sec'] = value * 1.16e-05
	elif units == 'UK gph':
		returnDict['BPD'] = value * 0.6862571
		returnDict['BPH'] = value * 0.028594
		returnDict['BPM'] = value * 0.0004766
		returnDict['BPS'] = value * 7.9e-06
		returnDict['ft3/day'] = value * 3.853054
		returnDict['ft3/hr'] = value * 0.1605439
		returnDict['ft3/min'] = value * 0.0026757
		returnDict['ft3/sec'] = value * 4.46e-05
		returnDict['m3/day'] = value * 0.1091062
		returnDict['m3/hr'] = value * 0.0045461
		returnDict['m3/min'] = value * 7.58e-05
		returnDict['gal/day'] = value * 28.8228118
		returnDict['gph'] = value * 1.2009505
		returnDict['gpm'] = value * 0.0200158
		returnDict['gal/sec'] = value * 0.0003336
		returnDict['UK gal/day'] = value * 24.0
		returnDict['UK gph'] = value
		returnDict['UK gpm'] = value * 0.0166667
		returnDict['UK gal/sec'] = value * 0.0002778
	elif units == 'UK gpm':
		returnDict['BPD'] = value * 41.1754247
		returnDict['BPH'] = value * 1.7156427
		returnDict['BPM'] = value * 0.028594
		returnDict['BPS'] = value * 0.0004766
		returnDict['ft3/day'] = value * 231.183241
		returnDict['ft3/hr'] = value * 9.632635
		returnDict['ft3/min'] = value * 0.1605439
		returnDict['ft3/sec'] = value * 0.0026757
		returnDict['m3/day'] = value * 6.5463696
		returnDict['m3/hr'] = value * 0.2727654
		returnDict['m3/min'] = value * 0.0045461
		returnDict['gal/day'] = value * 1729.3687077
		returnDict['gph'] = value * 72.0570295
		returnDict['gpm'] = value * 1.2009505
		returnDict['gal/sec'] = value * 0.0200158
		returnDict['UK gal/day'] = value * 1440.0
		returnDict['UK gph'] = value * 60.0
		returnDict['UK gpm'] = value
		returnDict['UK gal/sec'] = value * 0.0166667
	elif units == 'UK gal/sec':
		returnDict['BPD'] = value * 2470.5254822
		returnDict['BPH'] = value * 102.9385618
		returnDict['BPM'] = value * 1.7156427
		returnDict['BPS'] = value * 0.028594
		returnDict['ft3/day'] = value * 13870.9944627
		returnDict['ft3/hr'] = value * 577.9581026
		returnDict['ft3/min'] = value * 9.632635
		returnDict['ft3/sec'] = value * 0.1605439
		returnDict['m3/day'] = value * 392.782176
		returnDict['m3/hr'] = value * 16.365924
		returnDict['m3/min'] = value * 0.2727654
		returnDict['gal/day'] = value * 103762.1224649
		returnDict['gph'] = value * 4323.4217694
		returnDict['gpm'] = value * 72.0570295
		returnDict['gal/sec'] = value * 1.2009505
		returnDict['UK gal/day'] = value * 86400.0
		returnDict['UK gph'] = value * 3600.0
		returnDict['UK gpm'] = value * 60.0
		returnDict['UK gal/sec'] = value
	return returnDict


def viscocity(value, units):
	returnDict = {}
	if units == 'cp':
		returnDict['cp'] = value
		returnDict['g/(cm.s)'] = value * 0.01
		returnDict['kg/(m.hr)'] = value * 3.6
		returnDict['kg/(m.s)'] = value * 0.001
		returnDict['kg-f.s/m2'] = value * 0.000102
		returnDict['kPa-s'] = value * 1e-06
		returnDict['N.s/m2'] = value * 0.001
		returnDict['Pa-s'] = value * 0.001
		returnDict['dyne-s/cm2'] = value * 0.01
		returnDict['lbf-s/ft2'] = value * 2.09e-05
		returnDict['lbf-s/in2'] = value * 1.450377e-07
		returnDict['lb/(ft.hr)'] = value * 2.4190883
		returnDict['lb/(ft.s)'] = value * 0.000672
		returnDict['poundal.s/ft2'] = value * 0.000672
		returnDict['reyn'] = value * 1.450377e-07
	elif units == 'g/(cm.s)':
		returnDict['cp'] = value * 100.0
		returnDict['g/(cm.s)'] = value
		returnDict['kg/(m.hr)'] = value * 359.9999971
		returnDict['kg/(m.s)'] = value * 0.1
		returnDict['kg-f.s/m2'] = value * 0.0101972
		returnDict['kPa-s'] = value * 0.0001
		returnDict['N.s/m2'] = value * 0.1
		returnDict['Pa-s'] = value * 0.1
		returnDict['dyne-s/cm2'] = value
		returnDict['lbf-s/ft2'] = value * 0.0020885
		returnDict['lbf-s/in2'] = value * 1.45e-05
		returnDict['lb/(ft.hr)'] = value * 241.9088329
		returnDict['lb/(ft.s)'] = value * 0.0671969
		returnDict['poundal.s/ft2'] = value * 0.0671969
		returnDict['reyn'] = value * 1.45e-05
	elif units == 'kg/(m.hr)':
		returnDict['cp'] = value * 0.2777778
		returnDict['g/(cm.s)'] = value * 0.0027778
		returnDict['kg/(m.hr)'] = value
		returnDict['kg/(m.s)'] = value * 0.0002778
		returnDict['kg-f.s/m2'] = value * 2.83e-05
		returnDict['kPa-s'] = value * 2.777778e-07
		returnDict['N.s/m2'] = value * 0.000278
		returnDict['Pa-s'] = value * 0.0002778
		returnDict['dyne-s/cm2'] = value * 0.0027778
		returnDict['lbf-s/ft2'] = value * 5.8e-06
		returnDict['lbf-s/in2'] = value * 4.02781e-08
		returnDict['lb/(ft.hr)'] = value * 0.671969
		returnDict['lb/(ft.s)'] = value * 0.0001867
		returnDict['poundal.s/ft2'] = value * 0.0001867
		returnDict['reyn'] = value * 4.02781e-08
	elif units == 'kg/(m.s)':
		returnDict['cp'] = value * 1000.0
		returnDict['g/(cm.s)'] = value * 10.0
		returnDict['kg/(m.hr)'] = value * 3599.9999712
		returnDict['kg/(m.s)'] = value
		returnDict['kg-f.s/m2'] = value * 0.1019716
		returnDict['kPa-s'] = value * 0.001
		returnDict['N.s/m2'] = value
		returnDict['Pa-s'] = value
		returnDict['dyne-s/cm2'] = value * 10.0
		returnDict['lbf-s/ft2'] = value * 0.0208854
		returnDict['lbf-s/in2'] = value * 0.000145
		returnDict['lb/(ft.hr)'] = value * 2419.0883293
		returnDict['lb/(ft.s)'] = value * 0.671969
		returnDict['poundal.s/ft2'] = value * 0.671969
		returnDict['reyn'] = value * 0.000145
	elif units == 'kg-f.s/m2':
		returnDict['cp'] = value * 9806.65
		returnDict['g/(cm.s)'] = value * 98.0665
		returnDict['kg/(m.hr)'] = value * 35303.9397176
		returnDict['kg/(m.s)'] = value * 9.80665
		returnDict['kg-f.s/m2'] = value
		returnDict['kPa-s'] = value * 0.0098067
		returnDict['N.s/m2'] = value * 9.80665
		returnDict['Pa-s'] = value * 9.80665
		returnDict['dyne-s/cm2'] = value * 98.0665
		returnDict['lbf-s/ft2'] = value * 0.2048161
		returnDict['lbf-s/in2'] = value * 0.0014223
		returnDict['lb/(ft.hr)'] = value * 23723.1525646
		returnDict['lb/(ft.s)'] = value * 6.5897646
		returnDict['poundal.s/ft2'] = value * 6.5897646
		returnDict['reyn'] = value * 0.0014223
	elif units == 'kPa-s':
		returnDict['cp'] = value * 1000000.0
		returnDict['g/(cm.s)'] = value * 10000.0
		returnDict['kg/(m.hr)'] = value * 3599999.9712
		returnDict['kg/(m.s)'] = value * 1000.0
		returnDict['kg-f.s/m2'] = value * 101.9716213
		returnDict['kPa-s'] = value
		returnDict['N.s/m2'] = value * 1000.0
		returnDict['Pa-s'] = value * 1000.0
		returnDict['dyne-s/cm2'] = value * 10000.0
		returnDict['lbf-s/ft2'] = value * 20.8854342
		returnDict['lbf-s/in2'] = value * 0.1450377
		returnDict['lb/(ft.hr)'] = value * 2419088.3293091
		returnDict['lb/(ft.s)'] = value * 671.9689751
		returnDict['poundal.s/ft2'] = value * 671.9689751
		returnDict['reyn'] = value * 0.1450377
	elif units == 'N.s/m2':
		returnDict['cp'] = value * 1000.0
		returnDict['g/(cm.s)'] = value * 10.0
		returnDict['kg/(m.hr)'] = value * 3599.9999712
		returnDict['kg/(m.s)'] = value
		returnDict['kg-f.s/m2'] = value * 0.1019716
		returnDict['kPa-s'] = value * 0.001
		returnDict['N.s/m2'] = value
		returnDict['Pa-s'] = value
		returnDict['dyne-s/cm2'] = value * 10.0
		returnDict['lbf-s/ft2'] = value * 0.0208854
		returnDict['lbf-s/in2'] = value * 0.000145
		returnDict['lb/(ft.hr)'] = value * 2419.0883293
		returnDict['lb/(ft.s)'] = value * 0.671969
		returnDict['poundal.s/ft2'] = value * 0.671969
		returnDict['reyn'] = value * 0.000145
	elif units == 'Pa-s':
		returnDict['cp'] = value * 1000.0
		returnDict['g/(cm.s)'] = value * 10.0
		returnDict['kg/(m.hr)'] = value * 3599.9999712
		returnDict['kg/(m.s)'] = value
		returnDict['kg-f.s/m2'] = value * 0.1019716
		returnDict['kPa-s'] = value * 0.001
		returnDict['N.s/m2'] = value
		returnDict['Pa-s'] = value
		returnDict['dyne-s/cm2'] = value * 10.0
		returnDict['lbf-s/ft2'] = value * 0.0208854
		returnDict['lbf-s/in2'] = value * 0.000145
		returnDict['lb/(ft.hr)'] = value * 2419.0883293
		returnDict['lb/(ft.s)'] = value * 0.671969
		returnDict['poundal.s/ft2'] = value * 0.671969
		returnDict['reyn'] = value * 0.000145
	elif units == 'dyne-s/cm2':
		returnDict['cp'] = value * 100.0
		returnDict['g/(cm.s)'] = value
		returnDict['kg/(m.hr)'] = value * 359.9999971
		returnDict['kg/(m.s)'] = value * 0.1
		returnDict['kg-f.s/m2'] = value * 0.0101972
		returnDict['kPa-s'] = value * 0.0001
		returnDict['N.s/m2'] = value * 0.1
		returnDict['Pa-s'] = value * 0.1
		returnDict['dyne-s/cm2'] = value
		returnDict['lbf-s/ft2'] = value * 0.0020885
		returnDict['lbf-s/in2'] = value * 1.45e-05
		returnDict['lb/(ft.hr)'] = value * 241.9088329
		returnDict['lb/(ft.s)'] = value * 0.0671969
		returnDict['poundal.s/ft2'] = value * 0.0671969
		returnDict['reyn'] = value * 1.45e-05
	elif units == 'lbf-s/ft2':
		returnDict['cp'] = value * 47880.2589803
		returnDict['g/(cm.s)'] = value * 478.8025898
		returnDict['kg/(m.hr)'] = value * 172368.9309503
		returnDict['kg/(m.s)'] = value * 47.880259
		returnDict['kg-f.s/m2'] = value * 4.8824276
		returnDict['kPa-s'] = value * 0.0478803
		returnDict['N.s/m2'] = value * 47.880259
		returnDict['Pa-s'] = value * 47.880259
		returnDict['dyne-s/cm2'] = value * 478.8025898
		returnDict['lbf-s/ft2'] = value
		returnDict['lbf-s/in2'] = value * 0.0069444
		returnDict['lb/(ft.hr)'] = value * 115826.5757036
		returnDict['lb/(ft.s)'] = value * 32.1740486
		returnDict['poundal.s/ft2'] = value * 32.1740486
		returnDict['reyn'] = value * 0.0069444
	elif units == 'lbf-s/in2':
		returnDict['cp'] = value * 6894757.293
		returnDict['g/(cm.s)'] = value * 68947.57293
		returnDict['kg/(m.hr)'] = value * 24821126.056231
		returnDict['kg/(m.s)'] = value * 6894.757293
		returnDict['kg-f.s/m2'] = value * 703.0695796
		returnDict['kPa-s'] = value * 6.8947573
		returnDict['N.s/m2'] = value * 6894.757293
		returnDict['Pa-s'] = value * 6894.757293
		returnDict['dyne-s/cm2'] = value * 68947.57293
		returnDict['lbf-s/ft2'] = value * 144.0
		returnDict['lbf-s/in2'] = value
		returnDict['lb/(ft.hr)'] = value * 16679026.9009154
		returnDict['lb/(ft.s)'] = value * 4633.062992
		returnDict['poundal.s/ft2'] = value * 4633.062992
		returnDict['reyn'] = value * 0.9997398074849999
	elif units == 'lb/(ft.hr)':
		returnDict['cp'] = value * 0.4133789
		returnDict['g/(cm.s)'] = value * 0.0041338
		returnDict['kg/(m.hr)'] = value * 1.4881639
		returnDict['kg/(m.s)'] = value * 0.0004134
		returnDict['kg-f.s/m2'] = value * 4.22e-05
		returnDict['kPa-s'] = value * 4.1384274e-07
		returnDict['N.s/m2'] = value * 0.0004134
		returnDict['Pa-s'] = value * 0.0004134
		returnDict['dyne-s/cm2'] = value * 0.0041338
		returnDict['lbf-s/ft2'] = value * 8.6e-06
		returnDict['lbf-s/in2'] = value * 5.972184e-08
		returnDict['lb/(ft.hr)'] = value
		returnDict['lb/(ft.s)'] = value * 0.0002778
		returnDict['poundal.s/ft2'] = value * 0.0002778
		returnDict['reyn'] = value * 5.99401e-08
	elif units == 'lb/(ft.s)':
		returnDict['cp'] = value * 1488.1639436
		returnDict['g/(cm.s)'] = value * 14.8816394
		returnDict['kg/(m.hr)'] = value * 5357.390154
		returnDict['kg/(m.s)'] = value * 1.4881639
		returnDict['kg-f.s/m2'] = value * 0.1517505
		returnDict['kPa-s'] = value * 0.0014882
		returnDict['N.s/m2'] = value * 1.4881639
		returnDict['Pa-s'] = value * 1.4881639
		returnDict['dyne-s/cm2'] = value * 14.8816394
		returnDict['lbf-s/ft2'] = value * 0.031081
		returnDict['lbf-s/in2'] = value * 0.0002158
		returnDict['lb/(ft.hr)'] = value * 3600.000028
		returnDict['lb/(ft.s)'] = value
		returnDict['poundal.s/ft2'] = value
		returnDict['reyn'] = value * 0.0002157837713
	elif units == 'poundal.s/ft2':
		returnDict['cp'] = value * 1488.1639436
		returnDict['g/(cm.s)'] = value * 14.8816394
		returnDict['kg/(m.hr)'] = value * 5357.390154
		returnDict['kg/(m.s)'] = value * 1.4881639
		returnDict['kg-f.s/m2'] = value * 0.1517505
		returnDict['kPa-s'] = value * 0.0014882
		returnDict['N.s/m2'] = value * 1.4881639
		returnDict['Pa-s'] = value * 1.4881639
		returnDict['dyne-s/cm2'] = value * 14.8816394
		returnDict['lbf-s/ft2'] = value * 0.031081
		returnDict['lbf-s/in2'] = value * 0.0002158
		returnDict['lb/(ft.hr)'] = value * 3600.000028
		returnDict['lb/(ft.s)'] = value
		returnDict['poundal.s/ft2'] = value
		returnDict['reyn'] = value * 0.0002157837713
	elif units == 'reyn':
		returnDict['cp'] = value * 6894757.293
		returnDict['g/(cm.s)'] = value * 68947.57293
		returnDict['kg/(m.hr)'] = value * 24821126.056231
		returnDict['kg/(m.s)'] = value * 6894.757293
		returnDict['kg-f.s/m2'] = value * 703.0695796
		returnDict['kPa-s'] = value * 6.8947573
		returnDict['N.s/m2'] = value * 6894.757293
		returnDict['Pa-s'] = value * 6894.757293
		returnDict['dyne-s/cm2'] = value * 68947.57293
		returnDict['lbf-s/ft2'] = value * 144.0
		returnDict['lbf-s/in2'] = value * 0.9999936
		returnDict['lb/(ft.hr)'] = value * 16679026.9009154
		returnDict['lb/(ft.s)'] = value * 4633.062992
		returnDict['poundal.s/ft2'] = value * 4633.062992
		returnDict['reyn'] = value
	return returnDict


def oil_volume(value, units):
	returnDict = {}
	if units == 'bbl':
		returnDict['bbl'] = value
		returnDict['BOE'] = value
		returnDict['gal'] = value * 42.0
		returnDict['kL'] = value * 0.1589873
		returnDict['MMBOE'] = value * 1e-06
		returnDict['KBOE'] = value * 0.001
		returnDict['toe'] = value * 0.1363636
	elif units == 'BOE':
		returnDict['bbl'] = value
		returnDict['BOE'] = value
		returnDict['gal'] = value * 42.0
		returnDict['kL'] = value * 0.1589873
		returnDict['MMBOE'] = value * 1e-06
		returnDict['KBOE'] = value * 0.001
		returnDict['toe'] = value * 0.1363636
	elif units == 'gal':
		returnDict['bbl'] = value * 0.0238095
		returnDict['BOE'] = value * 0.0238095
		returnDict['gal'] = value
		returnDict['kL'] = value * 0.0037854
		returnDict['MMBOE'] = value * 2.38e-08
		returnDict['KBOE'] = value * 2.38e-05
		returnDict['toe'] = value * 0.0032468
	elif units == 'kL':
		returnDict['bbl'] = value * 6.2898108
		returnDict['BOE'] = value * 6.2898108
		returnDict['gal'] = value * 264.1720524
		returnDict['kL'] = value
		returnDict['MMBOE'] = value * 6.3e-06
		returnDict['KBOE'] = value * 0.0062898
		returnDict['toe'] = value * 0.8577015
	elif units == 'MMBOE':
		returnDict['bbl'] = value * 1000000.0
		returnDict['BOE'] = value * 1000000.0
		returnDict['gal'] = value * 42000000.0
		returnDict['kL'] = value * 158987.2949287
		returnDict['MMBOE'] = value
		returnDict['KBOE'] = value * 1000.0
		returnDict['toe'] = value * 136363.6363636
	elif units == 'KBOE':
		returnDict['bbl'] = value * 1000.0
		returnDict['BOE'] = value * 1000.0
		returnDict['gal'] = value * 42000.0
		returnDict['kL'] = value * 158.9872949
		returnDict['MMBOE'] = value * 0.001
		returnDict['KBOE'] = value
		returnDict['toe'] = value * 136.3636364
	elif units == 'toe':
		returnDict['bbl'] = value * 7.3333333
		returnDict['BOE'] = value * 7.3333333
		returnDict['gal'] = value * 308.0
		returnDict['kL'] = value * 1.1659068
		returnDict['MMBOE'] = value * 7.3e-06
		returnDict['KBOE'] = value * 0.0073333
		returnDict['toe'] = value
	return returnDict


from setuptools import setup

# This call to setup() does all the work
setup(
    name="ogPypeline",
    version='0.1.0',
    description='Unit conversion for oil and gas calculations',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    url="https://github.com/this-isnt-me/ogPypeline",
    author="Tim Clarke",
    author_email="<info@hitchadvisor.info>",
    license="MIT",
    classifiers=[
        "Development Status :: 3 - Alpha",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ],
    packages=["ogPypeline"],
    include_package_data=True,
    install_requires=[],
    keywords=['python', 'engineering', 'oil', 'gas',
              'energy', 'unit', 'conversion']
)
